MSG_HASH(
      MSG_COMPILER,
      "Compiler"
      )
MSG_HASH(
      MSG_UNKNOWN_COMPILER,
      "Onbekende compiler"
      )
MSG_HASH(
      MSG_DEVICE_DISCONNECTED_FROM_PORT,
      "Apparaat ontkoppeld van port"
      )
MSG_HASH(
      MSG_UNKNOWN_NETPLAY_COMMAND_RECEIVED,
      "Onbekend netplay commando ontvangen"
      )
MSG_HASH(
      MSG_FILE_ALREADY_EXISTS_SAVING_TO_BACKUP_BUFFER,
      "Bestand bestaat al. Saven naar backup buffer"
      )
MSG_HASH(
      MSG_GOT_CONNECTION_FROM,
      "Verbonden met: \"%s\""
      )
MSG_HASH(
      MSG_GOT_CONNECTION_FROM_NAME,
      "Verbonden met: \"%s (%s)\""
      )
MSG_HASH(
      MSG_NO_ARGUMENTS_SUPPLIED_AND_NO_MENU_BUILTIN,
      "No arguments supplied and no menu builtin, displaying help..."
      )
MSG_HASH(
      MSG_SETTING_DISK_IN_TRAY,
      "Setting disk in tray"
      )
MSG_HASH(
      MSG_WAITING_FOR_CLIENT,
      "Wachten op client ..."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SHARED_CONTEXT,
      "Give hardware-rendered cores their own private context. Avoids having to assume hardware state changes inbetween frames."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_SETTINGS,
      "Adjusts settings related to the appearance of the menu screen."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_HARD_SYNC,
      "Hard-synchronize the CPU and GPU. Reduces latency at the cost of performance."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_THREADED,
      "Verbetert prestaties ten kosten van latentie en meer video stotteringen. Gebruik dit enkel als het niet mogelijk is om full speed te bereiken zonder dit te activeren."
      )
MSG_HASH(
      MSG_AUDIO_VOLUME,
      "Geluidsvolume"
      )
MSG_HASH(
      MSG_AUTODETECT,
      "Autodetecteren"
      )
MSG_HASH(
      MSG_AUTOLOADING_SAVESTATE_FROM,
      "Auto-loading savestate from"
      )
MSG_HASH(
      MSG_CAPABILITIES,
      "Mogelijkheden"
      )
MSG_HASH(
      MSG_CONNECTING_TO_NETPLAY_HOST,
      "Verbinden met netplay host"
      )
MSG_HASH(
      MSG_CONNECTING_TO_PORT,
      "Verbinding maken met port"
      )
MSG_HASH(
      MSG_CONNECTION_SLOT,
      "Connectie slot"
      )
MSG_HASH(
      MSG_SORRY_UNIMPLEMENTED_CORES_DONT_DEMAND_CONTENT_NETPLAY,
      "Sorry, unimplemented: cores that don't demand content cannot participate in netplay."
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_PASSWORD,
      "Wachtwoord"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_SETTINGS,
      "Accounts Cheevos"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_USERNAME,
      "Gebruikersnaam"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_LIST,
      "Accounts"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_LIST_END,
      "Accounts List Endpoint"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_RETRO_ACHIEVEMENTS,
      "Retro Achievements"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACHIEVEMENT_LIST,
      "Achievements Lijst"
      )

MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACHIEVEMENT_LIST_HARDCORE,
      "Achievements Lijst (Hardcore)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ADD_CONTENT_LIST,
      "Inhoud toevoegen"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATIONS_LIST,
      "Configuraties"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ADD_TAB,
      "Importeer inhoud"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ASK_ARCHIVE,
      "Keuze"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ASSETS_DIRECTORY,
      "Assets"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_BLOCK_FRAMES,
      "Blok Frames"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DEVICE,
      "Audio Apparaat"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DRIVER,
      "Audio Driver"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DSP_PLUGIN,
      "Audio DSP Plugin"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_ENABLE,
      "Audio Activeren"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_FILTER_DIR,
      "Audio Filter"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_TURBO_DEADZONE_LIST,
      "Turbo/Deadzone"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_LATENCY,
      "Audio Latentie (ms)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MAX_TIMING_SKEW,
      "Audio Maximale Timing Onevenredigheid"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MUTE,
      "Audio Mute"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_OUTPUT_RATE,
      "Audio Uitvoer Frequentie (Hz)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_RATE_CONTROL_DELTA,
      "Dynamische Audio Rate Control"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_RESAMPLER_DRIVER,
      "Audio Resampler Driver"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_SETTINGS,
      "Geluid"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_SYNC,
      "Audio Synchronizatie"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_VOLUME,
      "Audio Uitgangsniveau (dB)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTOSAVE_INTERVAL,
      "Periodiek SaveRAM Autosaven"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_OVERRIDES_ENABLE,
      "Laad Override Bestanden Automatisch"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_REMAPS_ENABLE,
      "Laad Remap Bestanden Automatisch"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_SHADERS_ENABLE,
      "Load Shader Presets Automatically"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_BACK,
      "Terug"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_CONFIRM,
      "Bevestigen/OK"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_INFO,
      "Info"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_QUIT,
      "Afsluiten"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_SCROLL_DOWN,
      "Omlaag Scrollen"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_SCROLL_UP,
      "Omhoog Scrollen"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_START,
      "Start"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_TOGGLE_KEYBOARD,
      "Toggle Keyboard"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_TOGGLE_MENU,
      "Menu Schakelaar"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS,
      "Basis menu besturing"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_CONFIRM,
      "Bevestigen/OK"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_INFO,
      "Info"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_QUIT,
      "Afsluiten"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_SCROLL_UP,
      "Omhoog scrollen"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_START,
      "Standaard"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_TOGGLE_KEYBOARD,
      "Toggle Keyboard"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_TOGGLE_MENU,
      "Toggle Menu"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BLOCK_SRAM_OVERWRITE,
      "SaveRAM niet overschrijven tijdens laden van savestate"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BLUETOOTH_ENABLE,
      "Bluetooth Activeren"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BUILDBOT_ASSETS_URL,
      "Buildbot Assets URL"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CACHE_DIRECTORY,
      "Cache"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CAMERA_ALLOW,
      "Camera Toestaan"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CAMERA_DRIVER,
      "Camera Driver"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT,
      "Cheat"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_APPLY_CHANGES,
      "Cheat wijzigingen toepassen"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_DATABASE_PATH,
      "Cheats"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE,
      "Cheat Bestand"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE_LOAD,
      "Laad Cheat Bestand"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE_SAVE_AS,
      "Cheats Opslaan Als"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_NUM_PASSES,
      "Cheat Passes"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_DESCRIPTION,
      "Omschrijving"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_HARDCORE_MODE_ENABLE,
      "Hardcore Mode"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_LOCKED_ACHIEVEMENTS,
      "Locked Achievements:"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_LOCKED_ENTRY,
      "Locked"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_SETTINGS,
      "Retro Achievements"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_TEST_UNOFFICIAL,
      "Test Onofficiele Achievements"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ACHIEVEMENTS,
      "Unlocked Achievements:"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ENTRY,
      "Unlocked"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CLOSE_CONTENT,
      "Afsluiten"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIG,
      "Configuratie"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATIONS,
      "Configuratie laden"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATION_SETTINGS,
      "Configuratie"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIG_SAVE_ON_EXIT,
      "Configuratie Opslaan Tijdens Afsluiten"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_COLLECTION_LIST,
      "Collecties"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_DATABASE_DIRECTORY,
      "Inhoud Database"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_DIR,
      "Inhoud"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_HISTORY_SIZE,
      "Geschiedenislijst grootte")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SETTINGS,
      "Snelmenu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ASSETS_DIR,
      "Downloads")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ASSETS_DIRECTORY,
      "Downloads")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_CHEAT_OPTIONS,
      "Cheats")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_COUNTERS,
      "Core Prestatie tellers")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ENABLE,
      "Core naam weergeven")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFORMATION,
      "Core Informatie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_AUTHORS,
      "Auteurs")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CATEGORIES,
      "Categorieen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CORE_LABEL,
      "Core label")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CORE_NAME,
      "Core naam")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_FIRMWARE,
      "Firmware(s)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_LICENSES,
      "Licentie(s)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_PERMISSIONS,
      "Permissies")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SUPPORTED_EXTENSIONS,
      "Ondersteunde extensies")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SYSTEM_MANUFACTURER,
      "Systeem fabrikant")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SYSTEM_NAME,
      "Systeem naam")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INPUT_REMAPPING_OPTIONS,
      "Besturing")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_LIST,
      "Core Laden")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_OPTIONS,
      "Opties")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_SETTINGS,
      "Core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_SET_SUPPORTS_NO_CONTENT_ENABLE,
      "Automatisch core opstarten")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_AUTO_EXTRACT_ARCHIVE,
      "Automatisch uitpakken van gedownloade archieven")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_BUILDBOT_URL,
      "Buildbot Cores URL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_LIST,
      "Core Updater")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_SETTINGS,
      "Updater")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CPU_ARCHITECTURE,
      "CPU Architectuur:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CPU_CORES,
      "CPU Cores:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CURSOR_DIRECTORY,
      "Cursor")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CURSOR_MANAGER,
      "Cursor Beheer")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CUSTOM_RATIO,
      "Handmatige Beeldverhouding")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_MANAGER,
      "Database Beheer")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_SELECTION,
      "Database Selectie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DELETE_ENTRY,
      "Verwijderen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FAVORITES,
      "Favorieten")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_CONTENT,
      "<Content dir>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_DEFAULT,
      "<Standaard>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_NONE,
      "<Niets>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_NOT_FOUND,
      "Directory niet gevonden.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_SETTINGS,
      "Directory")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_CYCLE_TRAY_STATUS,
      "Disk Cycle Tray Status")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_IMAGE_APPEND,
      "Disk Image Toevoegen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_INDEX,
      "Disk Index")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_OPTIONS,
      "Disk Beheer")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DONT_CARE,
      "Onbelangrijk")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOADED_FILE_DETECT_CORE_LIST,
      "Downloads")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOAD_CORE,
      "Download Core...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOAD_CORE_CONTENT,
      "Download Inhoud")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DPI_OVERRIDE_ENABLE,
      "DPI Override Activeren")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DPI_OVERRIDE_VALUE,
      "DPI Override")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DRIVER_SETTINGS,
      "Driver")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DUMMY_ON_CORE_SHUTDOWN,
      "Dummy Laden Tijdens Afsluiten")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DYNAMIC_WALLPAPER,
      "Dynamische Wallpaper")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DYNAMIC_WALLPAPERS_DIRECTORY,
      "Dynamische Wallpapers")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CHEEVOS_ENABLE,
      "Achievements Activeren")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ENTRY_HOVER_COLOR,
      "Menu entry hover kleur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ENTRY_NORMAL_COLOR,
      "Menu entry normale kleur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FALSE,
      "Niet waar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FASTFORWARD_RATIO,
      "Maximale afspeelsnelheid")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FPS_SHOW,
      "Framerate weergeven")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRAME_THROTTLE_ENABLE,
      "Beperk Maximale Afspeelsnelheid")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRAME_THROTTLE_SETTINGS,
      "Frame Throttle")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRONTEND_COUNTERS,
      "Frontend Prestatie Tellers")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS,
      "Load Content-Specific Core Options Automatically")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS_CREATE,
      "Create game-options file")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS_IN_USE,
      "Game-options file")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP,
      "hulp")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_AUDIO_VIDEO_TROUBLESHOOTING,
      "Audio/Video Raadpleging")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_CHANGE_VIRTUAL_GAMEPAD,
      "Virtuele Gamepad Overlay Veranderen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_CONTROLS,
      "Basis Menu Besturing")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_LIST,
      "Hulp")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_LOADING_CONTENT,
      "Hoe Laad je Content?")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_SCANNING_CONTENT,
      "Scannen naar Content")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_WHAT_IS_A_CORE,
      "Wat is een Core?")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HISTORY_LIST_ENABLE,
      "Geschiedenislijst Activeren")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HISTORY_TAB,
      "Geschiedenis")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HORIZONTAL_MENU,
      "Horizontale Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_IMAGES_TAB,
      "Afbeeldingen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INFORMATION,
      "Informatie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INFORMATION_LIST,
      "Informatie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ADC_TYPE,
      "Analog To Digital Type")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ALL_USERS_CONTROL_MENU,
      "All Users Control Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X,
      "Left Analog X")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X_MINUS,
      "Left analog X- (left)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X_PLUS,
      "Left analog X+ (right)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y,
      "Left Analog Y")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y_MINUS,
      "Left analog Y- (up)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y_PLUS,
      "Left analog Y+ (down)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X,
      "Right Analog X")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X_MINUS,
      "Right analog X- (left)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X_PLUS,
      "Right analog X+ (right)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y,
      "Right Analog Y")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y_MINUS,
      "Right analog Y- (up)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y_PLUS,
      "Right analog Y+ (down)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_TRIGGER,
      "Gun Trigger")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_RELOAD,
      "Gun Reload")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_A,
      "Gun Aux A")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_B,
      "Gun Aux B")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_C,
      "Gun Aux C")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_START,
      "Gun Start")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_SELECT,
      "Gun Select")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_UP,
      "Gun D-pad Up")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_DOWN,
      "Gun D-pad Down")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_LEFT,
      "Gun D-pad Left")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_RIGHT,
      "Gun D-pad Right")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_AUTODETECT_ENABLE,
      "Autoconfiguratie Activeren")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_AXIS_THRESHOLD,
      "Analoge As Deadzone")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_INPUT_SWAP_OK_CANCEL,
      "Menu Swap OK & Cancel Buttons")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_ALL,
      "Bind All")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_DEFAULT_ALL,
      "Bind Default All")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_TIMEOUT,
      "Bind Timeout")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DESCRIPTOR_HIDE_UNBOUND,
      "Verbergen Niet-gemapte Core Input Descripties")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DESCRIPTOR_LABEL_SHOW,
      "Descriptie Labels Weergeven")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DEVICE_INDEX,
      "Device Index")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DEVICE_TYPE,
      "Device Type")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DRIVER,
      "Input Driver")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DUTY_CYCLE,
      "Duty Cycle")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_HOTKEY_BINDS,
      "Invoer Hotkey Binds")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ICADE_ENABLE,
      "Keyboard Gamepad Mapping Enable")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_A,
      "A knop (right)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_B,
      "B knop (down)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_DOWN,
      "Down D-pad")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L2,
      "L2 knop (trigger)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L3,
      "L3 knop (thumb)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L,
      "L knop (shoulder)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_LEFT,
      "Left D-pad")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R2,
      "R2 knop (trigger)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R3,
      "R3 knop (thumb)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R,
      "R knop (shoulder)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_RIGHT,
      "Rechter D-pad")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_SELECT,
      "Select knop")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_START,
      "Start knop")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_UP,
      "Up D-pad")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_X,
      "X knop (top)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_Y,
      "Y knop (left)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_KEY,
      "(Key: %s)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_LEFT,
      "Mouse 1")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_RIGHT,
      "Mouse 2")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_MIDDLE,
      "Mouse 3")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_BUTTON4,
      "Mouse 4")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_BUTTON5,
      "Mouse 5")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_WHEEL_UP,
      "Wheel Up")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_WHEEL_DOWN,
      "Wheel Down")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_HORIZ_WHEEL_UP,
      "Wheel Left")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_HORIZ_WHEEL_DOWN,
      "Wheel Right")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_KEYBOARD_GAMEPAD_MAPPING_TYPE,
      "Keyboard Gamepad Mapping Type")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MAX_USERS,
      "Maximaal Aantal Gebruikers")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MENU_ENUM_TOGGLE_GAMEPAD_COMBO,
      "Menu Schakelaar Gamepad Combo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_INDEX_MINUS,
      "Cheat index -")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_INDEX_PLUS,
      "Cheat index +")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_TOGGLE,
      "Cheat toggle")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_EJECT_TOGGLE,
      "Disk eject toggle")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_NEXT,
      "Disk next")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_PREV,
      "Disk prev")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_ENABLE_HOTKEY,
      "Enable hotkeys")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FAST_FORWARD_HOLD_KEY,
      "Fast forward hold")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FAST_FORWARD_KEY,
      "Fast forward toggle")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FRAMEADVANCE,
      "Frameadvance")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FULLSCREEN_TOGGLE_KEY,
      "Fullscreen toggle")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_GRAB_MOUSE_TOGGLE,
      "Grab mouse toggle")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_LOAD_STATE_KEY,
      "Load state")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MENU_TOGGLE,
      "Menu toggle")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MOVIE_RECORD_TOGGLE,
      "Movie record toggle")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MUTE,
      "Audio mute toggle")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_OSK,
      "On-screen keyboard toggle")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_OVERLAY_NEXT,
      "Overlay next")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_PAUSE_TOGGLE,
      "Pause toggle")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_QUIT_KEY,
      "Sluit RetroArch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_RESET,
      "Reset game")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_REWIND,
      "Rewind")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SAVE_STATE_KEY,
      "Save state")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SCREENSHOT,
      "Take screenshot")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SHADER_NEXT,
      "Next shader")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SHADER_PREV,
      "Previous shader")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SLOWMOTION_HOLD_KEY,
      "Slow motion")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_STATE_SLOT_MINUS,
      "Savestate slot -")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_STATE_SLOT_PLUS,
      "Savestate slot +")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_VOLUME_DOWN,
      "Volume -")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_VOLUME_UP,
      "Volume +")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_ENABLE,
      "Overlay Weergeven")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_HIDE_IN_MENU,
      "Verberg Overlay In Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR,
      "Poll Type Behavior")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_EARLY,
      "Vroeg")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_LATE,
      "Laat")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_NORMAL,
      "Normaal")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_PREFER_FRONT_TOUCH,
      "Prefer Front Touch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_REMAPPING_DIRECTORY,
      "Input Remapping")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_REMAP_BINDS_ENABLE,
      "Remap Binds Activeren")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SAVE_AUTOCONFIG,
      "Autoconfig Opslaan")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SETTINGS,
      "Invoer")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SMALL_KEYBOARD_ENABLE,
      "Small Keyboard Enable")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TOUCH_ENABLE,
      "Touch Enable")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TURBO_ENABLE,
      "Turbo enable")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TURBO_PERIOD,
      "Turbo Period")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_USER_BINDS,
      "Invoer Gebruiker %u Binds")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INTERNAL_STORAGE_STATUS,
      "Internal storage status")
MSG_HASH(MENU_ENUM_LABEL_VALUE_JOYPAD_AUTOCONFIG_DIR,
      "Invoerapparaten Autoconfiguratie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_JOYPAD_DRIVER,
      "Joypad Driver")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LAKKA_SERVICES,
      "Services")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_CHINESE_SIMPLIFIED,
      "Chinees (Gesimplificeerd)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_CHINESE_TRADITIONAL,
      "Chinees (Traditioneel)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_DUTCH,
      "Nederlands")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ENGLISH,
      "Engels")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ESPERANTO,
      "Esperanto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_FRENCH,
      "Frans")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_GERMAN,
      "Duits")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ITALIAN,
      "Italiaans")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_JAPANESE,
      "Japans")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_KOREAN,
      "Koreaans")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_POLISH,
      "Pools")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_PORTUGUESE_BRAZIL,
      "Portugees (Brazil)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_PORTUGUESE_PORTUGAL,
      "Portugees (Portugal)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_RUSSIAN,
      "Russisch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_SPANISH,
      "Spaans")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_VIETNAMESE,
      "Vietnamees")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ARABIC,
      "Arabic")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LEFT_ANALOG,
      "Linkse Analoog Stick")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_DIR_PATH,
      "Core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_INFO_PATH,
      "Core Info")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_LOG_LEVEL,
      "Core Logging Level")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LINEAR,
      "Linear")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_ARCHIVE,
      "Laad Archief")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_HISTORY,
      "Recentelijk gebruikt")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_LIST,
      "Laad Inhoud")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_STATE,
      "Laad State")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOCATION_ALLOW,
      "Locatie toestaan")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOCATION_DRIVER,
      "Locatie Driver")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOGGING_SETTINGS,
      "Logging")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOG_VERBOSITY,
      "Logging Niveau")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MAIN_MENU,
      "Hoofdmenu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MANAGEMENT,
      "Database Instellingen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME,
      "Menu Kleur Thema")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_BLUE,
      "Blauw")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_BLUE_GREY,
      "Blauw Grijs")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_DARK_BLUE,
      "Donker Blauw")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_GREEN,
      "Groen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_NVIDIA_SHIELD,
      "Shield")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_RED,
      "Rood")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_YELLOW,
      "Geel")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_FOOTER_OPACITY,
      "Footer Opacity")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_HEADER_OPACITY,
      "Header Opacity")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_DRIVER,
      "Menu Driver")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_ENUM_THROTTLE_FRAMERATE,
      "Throttle Menu Framerate")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FILE_BROWSER_SETTINGS,
      "Instellingen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_LINEAR_FILTER,
      "Menu Linear Filter")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SETTINGS,
      "Uiterlijk")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_WALLPAPER,
      "Achtergrond")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_WALLPAPER_OPACITY,
      "Achtergrond doorzichtigheid")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MISSING,
      "Ontbrekend")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MORE,
      "...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MOUSE_ENABLE,
      "Muis Ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MULTIMEDIA_SETTINGS,
      "Multimedia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MUSIC_TAB,
      "Muziek")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NAVIGATION_BROWSER_FILTER_SUPPORTED_EXTENSIONS_ENABLE,
      "Filtreer onbekende extensies")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NAVIGATION_WRAPAROUND,
      "Navigatie Wrap-Around")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NEAREST,
      "Dichtstbijzijnde")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY,
      "Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_CHECK_FRAMES,
      "Netplay Check Frames")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DELAY_FRAMES,
      "Netplay Vertraging Frames")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DISCONNECT,
      "Disconnect")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE,
      "Netplay Activeren")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE_CLIENT,
      "Connect to Netplay host")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE_HOST,
      "Begin hosting")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DISABLE_HOST,
      "Eindig netplay host")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_IP_ADDRESS,
      "Server Adres")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_MODE,
      "Netplay Client Activeren")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_NICKNAME,
      "Gebruikersnaam")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SETTINGS,
      "Netplay settings")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SPECTATOR_MODE_ENABLE,
      "Netplay Spectator Activeren")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_TCP_UDP_PORT,
      "Netplay TCP/UDP Poort")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_CMD_ENABLE,
      "Netwerk Commando's")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_CMD_PORT,
      "Netwerk Commando Poort")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_INFORMATION,
      "Netwerk Informatie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_REMOTE_ENABLE,
      "Netwerk Gamepad")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_REMOTE_PORT,
      "Netwerk Remote Base Port")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_SETTINGS,
      "Netwerk")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO,
      "Nee")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NONE,
      "Geen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NOT_AVAILABLE,
      "N.v.t")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ACHIEVEMENTS_TO_DISPLAY,
      "No achievements to display.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE,
      "Geen Core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORES_AVAILABLE,
      "Geen cores beschikbaar.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE_INFORMATION_AVAILABLE,
      "Geen core informatie beschikbaar.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE_OPTIONS_AVAILABLE,
      "Geen core opties beschikbaar.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ENTRIES_TO_DISPLAY,
      "No entries to display.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_HISTORY_AVAILABLE,
      "Geen geschiedenis beschikbaar.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_INFORMATION_AVAILABLE,
      "Informatie is niet beschikbaar.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ITEMS,
      "Geen items.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PERFORMANCE_COUNTERS,
      "Geen prestatie tellers.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PLAYLISTS,
      "No playlists.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PLAYLIST_ENTRIES_AVAILABLE,
      "Geen afspeellijst items beschikbaar.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_SETTINGS_FOUND,
      "Geen instellingen gevonden.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_SHADER_PARAMETERS,
      "Geen shader parameters.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OFF,
      "UIT")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ON,
      "AAN")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONLINE,
      "Online")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONLINE_UPDATER,
      "Online Updater")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_DISPLAY_SETTINGS,
      "Onscreen Weergave")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_OVERLAY_SETTINGS,
      "Onscreen Overlay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_NOTIFICATIONS_SETTINGS,
      "Onscreen Notifications")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OPEN_ARCHIVE,
      "Open Archief")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OPTIONAL,
      "Optioneel")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY,
      "Overlay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_AUTOLOAD_PREFERRED,
      "Laad geprefeerd overlay autom.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_DIRECTORY,
      "Overlay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_OPACITY,
      "Overlay Transparantie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_PRESET,
      "Overlay Preset")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_SCALE,
      "Overlay Schalering")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_SETTINGS,
      "Onscreen Overlay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAL60_ENABLE,
      "PAL60 Mode Activeren")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PARENT_DIRECTORY,
      "Parent directory")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAUSE_LIBRETRO,
      "Pauseer als menu op voorgrond is")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAUSE_NONACTIVE,
      "Laat niet in achtergrond draaien")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PERFCNT_ENABLE,
      "Prestatie Teller")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLISTS_TAB,
      "Afspeellijsten")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_DIRECTORY,
      "Afspeellijst")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_SETTINGS,
      "Playlists")
MSG_HASH(MENU_ENUM_LABEL_VALUE_POINTER_ENABLE,
      "Touch Ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PORT,
      "Poort")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PRESENT,
      "Aanwezig")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PRIVACY_SETTINGS,
      "Privacy")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUIT_RETROARCH,
      "Sluit RetroArch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ANALOG,
      "Analog supported")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_BBFC_RATING,
      "BBFC Rating")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_CERO_RATING,
      "CERO Rating")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_COOP,
      "Co-op supported")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_CRC32,
      "CRC32")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_DESCRIPTION,
      "Omschrijving")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_DEVELOPER,
      "Ontwikkelaar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_ISSUE,
      "Edge Magazine Issue")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_RATING,
      "Edge Magazine Rating")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_REVIEW,
      "Edge Magazine Review")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ELSPA_RATING,
      "ELSPA Rating")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ENHANCEMENT_HW,
      "Enhancement Hardware")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ESRB_RATING,
      "ESRB Rating")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_FAMITSU_MAGAZINE_RATING,
      "Famitsu Magazine Rating")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_FRANCHISE,
      "Franchise")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_GENRE,
      "Genre")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_MD5,
      "MD5")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_NAME,
      "Naam")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ORIGIN,
      "Afkomst")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_PEGI_RATING,
      "PEGI Rating")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_PUBLISHER,
      "Uitgever")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RELEASE_MONTH,
      "Release datum Maand")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RELEASE_YEAR,
      "Release datum Jaar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RUMBLE,
      "Rumble supported")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_SERIAL,
      "Serial")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_SHA1,
      "SHA1")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_START_CONTENT,
      "Content Opstarten")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_TGDB_RATING,
      "TGDB Rating")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REBOOT,
      "Herstart")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_CONFIG_DIRECTORY,
      "Opname Config Map")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_OUTPUT_DIRECTORY,
      "Opname Uitvoer Map")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_SETTINGS,
      "Opname")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_CONFIG,
      "Laad Opname Configuratie...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_DRIVER,
      "Opname Driver")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_ENABLE,
      "Opname Activeren")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_PATH,
      "Uitvoer Bestand Opslaan Als...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_USE_OUTPUT_DIRECTORY,
      "Gebruik Uitvoer Map")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE,
      "Remap File")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_LOAD,
      "Laad Remap Bestand")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_SAVE_CORE,
      "Core Remap Bestand Opslaan")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_SAVE_GAME,
      "Game Remap Bestand Opslaan")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REQUIRED,
      "Vereist")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESTART_CONTENT,
      "Opnieuw opstarten")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESTART_RETROARCH,
      "RetroArch Opnieuw Opstarten")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESUME,
      "Hervatten")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESUME_CONTENT,
      "Hervatten")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROKEYBOARD,
      "RetroKeyboard")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROPAD,
      "RetroPad")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROPAD_WITH_ANALOG,
      "RetroPad w/ Analog")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETRO_ACHIEVEMENTS_SETTINGS,
      "Achievements")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_ENABLE,
      "Rewind Activeren")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_GRANULARITY,
      "Rewind Granulariteit")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_SETTINGS,
      "Rewind")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_BROWSER_DIRECTORY,
      "Bestandsbeheer")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_CONFIG_DIRECTORY,
      "Config")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_SHOW_START_SCREEN,
      "Start Scherm Weergeven")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RIGHT_ANALOG,
      "Rechtse Analog Stick")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RUN,
      "Run")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAMBA_ENABLE,
      "SAMBA Enable")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVEFILE_DIRECTORY,
      "Savebestand")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_INDEX,
      "Save State Automatische Index")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_LOAD,
      "Automatisch State Loaden")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_SAVE,
      "Automatisch State Saven")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_DIRECTORY,
      "Savestate")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG,
      "Huidige Configuratie Opslaan")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG_OVERRIDE_CORE,
      "Save Core Overrides")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG_OVERRIDE_GAME,
      "Save Game Overrides")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_NEW_CONFIG,
      "Nieuwe configuratie opslaan")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_STATE,
      "Save State")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVING_SETTINGS,
      "Saving")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_DIRECTORY,
      "Scan Directory")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_FILE,
      "Scan Een Bestand")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_THIS_DIRECTORY,
      "<Scan Deze Map>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCREENSHOT_DIRECTORY,
      "Screenshot")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCREEN_RESOLUTION,
      "Scherm Resolutie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SEARCH,
      "Zoeken:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SECONDS,
      "secondes")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SETTINGS,
      "Instellingen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SETTINGS_TAB,
      "Instellingen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER,
      "Shader")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_APPLY_CHANGES,
      "Shader Instellingen Toepassen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_OPTIONS,
      "Shaders")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_RIBBON,
      "Ribbon")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_RIBBON_SIMPLIFIED,
      "Ribbon (vereenvoudigd)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SIMPLE_SNOW,
      "Simpel Sneeuw")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SNOW,
      "Sneeuw")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHOW_ADVANCED_SETTINGS,
      "Geavanceerde Instellingen weergeven")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHOW_HIDDEN_FILES,
      "Show Hidden Files and Folders")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHUTDOWN,
      "Shutdown")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SLOWMOTION_RATIO,
      "Slow-Motion Ratio")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SORT_SAVEFILES_ENABLE,
      "Saves Sorteren In Map")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SORT_SAVESTATES_ENABLE,
      "Savestates Sorteren In Map")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SSH_ENABLE,
      "SSH Enable")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_CORE,
      "Start Core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_NET_RETROPAD,
      "Start Remote RetroPad")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_VIDEO_PROCESSOR,
      "Start Video Processor")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATE_SLOT,
      "State Slot")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATUS,
      "Status")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STDIN_CMD_ENABLE,
      "stdin Commandos")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SUPPORTED_CORES,
      "Aanbevolen cores")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SUSPEND_SCREENSAVER_ENABLE,
      "Onderbreek Screensaver")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_BGM_ENABLE,
      "Systeem BGM Activeren")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_DIRECTORY,
      "Systeem/BIOS")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFORMATION,
      "Systeem Informatie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_7ZIP_SUPPORT,
      "7zip ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ALSA_SUPPORT,
      "ALSA ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_BUILD_DATE,
      "Build datum")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CG_SUPPORT,
      "Cg ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_COCOA_SUPPORT,
      "Cocoa ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_COMMAND_IFACE_SUPPORT,
      "Command interface ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CORETEXT_SUPPORT,
      "CoreText ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CPU_FEATURES,
      "CPU Eigenschappen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_DPI,
      "Display metric DPI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_MM_HEIGHT,
      "Display metric hoogte (mm)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_MM_WIDTH,
      "Display metric breedte (mm)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DSOUND_SUPPORT,
      "DirectSound ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_WASAPI_SUPPORT,
      "WASAPI ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DYLIB_SUPPORT,
      "Dynamic library ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DYNAMIC_SUPPORT,
      "Dynamic run-time loading of libretro library")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_EGL_SUPPORT,
      "EGL ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FBO_SUPPORT,
      "OpenGL/Direct3D render-to-texture (multi-pass shaders) ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FFMPEG_SUPPORT,
      "FFmpeg ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FREETYPE_SUPPORT,
      "FreeType ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_IDENTIFIER,
      "Frontend identificatie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_NAME,
      "Frontend naam")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_OS,
      "Frontend OS")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_GIT_VERSION,
      "Git versie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_GLSL_SUPPORT,
      "GLSL ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_HLSL_SUPPORT,
      "HLSL ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_JACK_SUPPORT,
      "JACK ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_KMS_SUPPORT,
      "KMS/EGL ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBRETRODB_SUPPORT,
      "LibretroDB ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBUSB_SUPPORT,
      "Libusb ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBXML2_SUPPORT,
      "libxml2 XML parsing ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETPLAY_SUPPORT,
      "Netplay (peer-to-peer) ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETWORK_COMMAND_IFACE_SUPPORT,
      "Network Command interface ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETWORK_REMOTE_SUPPORT,
      "Network Gamepad ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENAL_SUPPORT,
      "OpenAL ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENGLES_SUPPORT,
      "OpenGL ES ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENGL_SUPPORT,
      "OpenGL ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENSL_SUPPORT,
      "OpenSL ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENVG_SUPPORT,
      "OpenVG ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OSS_SUPPORT,
      "OSS ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OVERLAY_SUPPORT,
      "Overlay ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE,
      "Energie bron")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_CHARGED,
      "Opgeladen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_CHARGING,
      "Opladen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_DISCHARGING,
      "Discharging")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_NO_SOURCE,
      "Geen bron")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_PULSEAUDIO_SUPPORT,
      "PulseAudio ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_PYTHON_SUPPORT,
      "Python (script ondersteuning in shaders) ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RBMP_SUPPORT,
      "BMP ondersteuning (RBMP)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RETRORATING_LEVEL,
      "RetroRating level")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RJPEG_SUPPORT,
      "JPEG ondersteuning (RJPEG)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ROARAUDIO_SUPPORT,
      "RoarAudio ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RPNG_SUPPORT,
      "PNG ondersteuning (RPNG)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RSOUND_SUPPORT,
      "RSound ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RTGA_SUPPORT,
      "TGA ondersteuning (RTGA)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL2_SUPPORT,
      "SDL2 ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL_IMAGE_SUPPORT,
      "SDL image ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL_SUPPORT,
      "SDL1.2 ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SLANG_SUPPORT,
      "Slang ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_THREADING_SUPPORT,
      "Threading ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_UDEV_SUPPORT,
      "Udev ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_V4L2_SUPPORT,
      "Video4Linux2 ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_VIDEO_CONTEXT_DRIVER,
      "Video context driver")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_VULKAN_SUPPORT,
      "Vulkan ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_WAYLAND_SUPPORT,
      "Wayland ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_X11_SUPPORT,
      "X11 ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_XAUDIO2_SUPPORT,
      "XAudio2 ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_XVIDEO_SUPPORT,
      "XVideo ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ZLIB_SUPPORT,
      "Zlib ondersteuning")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TAKE_SCREENSHOT,
      "Neem Schermafdruk")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THREADED_DATA_RUNLOOP_ENABLE,
      "Threaded taken")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS,
      "Thumbnails")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS_DIRECTORY,
      "Thumbnails")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS_UPDATER_LIST,
      "Thumbnails Updater")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_BOXARTS,
      "Boxarts")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_SCREENSHOTS,
      "Screenshots")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_TITLE_SCREENS,
      "Title Screens")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TIMEDATE_ENABLE,
      "Tijd/datum weergeven")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TITLE_COLOR,
      "Menu titelkleur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TRUE,
      "Waar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_COMPANION_ENABLE,
      "UI Companion Enable")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_COMPANION_START_ON_BOOT,
      "UI Companion Start Tijdens Boot")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_MENUBAR_ENABLE,
      "Menubalk")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNABLE_TO_READ_COMPRESSED_FILE,
      "Fout opgetreden tijdens lezen van gecomprimeerd bestand.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNDO_LOAD_STATE,
      "Laden van State Ongedaan Maken")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNDO_SAVE_STATE,
      "Save State Ongedaan Maken")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNKNOWN,
      "Onbekend")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATER_SETTINGS,
      "Updater")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_ASSETS,
      "Update Assets")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_AUTOCONFIG_PROFILES,
      "Update Autoconfiguratie Profielen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CG_SHADERS,
      "Update Cg Shaders")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CHEATS,
      "Update Cheats")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CORE_INFO_FILES,
      "Update Core Info Bestanden")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_DATABASES,
      "Update Databases")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_GLSL_SHADERS,
      "Update GLSL Shaders")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_LAKKA,
      "Update Lakka")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_OVERLAYS,
      "Update Overlays")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_SLANG_SHADERS,
      "Update Slang Shaders")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER,
      "User")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_INTERFACE_SETTINGS,
      "Gebruikersinterface")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_LANGUAGE,
      "Taal")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_SETTINGS,
      "Gebruiker")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_BUILTIN_IMAGE_VIEWER,
      "Gebruik ingebouwde afbeeldingsweergave")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_BUILTIN_PLAYER,
      "Gebruik ingebouwde media speler")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_THIS_DIRECTORY,
      "<Gebruik deze map>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ALLOW_ROTATE,
      "Rotatie toestaan")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO_AUTO,
      "Automatische Beeldverhouding")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO_INDEX,
      "Beeldverhouding")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_BLACK_FRAME_INSERTION,
      "Zwarte Frame Injectie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_CROP_OVERSCAN,
      "Overscan Afsnijden (Herladen Vereist)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_DISABLE_COMPOSITION,
      "Desktop Compositie Deactiveren")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_DRIVER,
      "Video Driver")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER,
      "Video Filter")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER_DIR,
      "Video Filter")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER_FLICKER,
      "Flicker filter")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_ENABLE,
      "Onscreen Berichten Weergeven")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_PATH,
      "Onscreen Berichten Font")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_SIZE,
      "Onscreen Berichten Grootte")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FORCE_ASPECT,
      "Forceer beeldverhouding")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FORCE_SRGB_DISABLE,
      "Handmatig sRGB FBO Deactiveren")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FRAME_DELAY,
      "Frame Delay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FULLSCREEN,
      "Gebruik Fullscreen Mode")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GAMMA,
      "Video Gamma")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GPU_RECORD,
      "GPU Opname Activeren")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GPU_SCREENSHOT,
      "GPU Screenshots Activeren")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_HARD_SYNC,
      "Harde GPU Synchronisatie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_HARD_SYNC_FRAMES,
      "Harde GPU Sync Frames")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MAX_SWAPCHAIN_IMAGES,
      "Max swapchain images")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_POS_X,
      "OSD Berichten X-as positie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_POS_Y,
      "OSD Berichten Y-as positie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MONITOR_INDEX,
      "Monitor Index")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_POST_FILTER_RECORD,
      "Post Filter Opname Activeren")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE,
      "Vertical Refresh Rate")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE_AUTO,
      "Geschatte Scherm Framerate")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE_POLLED,
      "Set Display-Reported Refresh Rate")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ROTATION,
      "Rotatie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SCALE,
      "Venster Schalering")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SCALE_INTEGER,
      "Vierkantige schalering")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SETTINGS,
      "Video")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_DIR,
      "Video Shader")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_NUM_PASSES,
      "Shader Passes")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PARAMETERS,
      "Voorbeeldweergave Shader Parameters")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET,
      "Load Shader Preset")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_AS,
      "Shader Preset Opslaan Als")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_CORE,
      "Save Core Preset")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_GAME,
      "Save Game Preset")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHARED_CONTEXT,
      "Activeer Gedeelde Hardware Context")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SMOOTH,
      "Bilinear Filtering")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SOFT_FILTER,
      "Soft Filter Enable")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SWAP_INTERVAL,
      "Vertical Sync (Vsync) Swap Interval")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_TAB,
      "Video")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_THREADED,
      "Threaded Video")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VFILTER,
      "Deflicker")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_HEIGHT,
      "Handmatige Viewport Hoogte")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_WIDTH,
      "Handmatige Viewport Breedte")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_X,
      "Handmatige Viewport X Pos.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_Y,
      "Handmatige Viewport Y Positie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VI_WIDTH,
      "VI Scherm Breedte Instellen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VSYNC,
      "Verticale Sync (Vsync)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOWED_FULLSCREEN,
      "Windowed Fullscreen Mode")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_WIDTH,
      "Window Width")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_HEIGHT,
      "Window Height")
MSG_HASH(MENU_ENUM_LABEL_VALUE_WIFI_DRIVER,
      "Wi-Fi Driver")
MSG_HASH(MENU_ENUM_LABEL_VALUE_WIFI_SETTINGS,
      "Wi-Fi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ALPHA_FACTOR,
      "Menu Alpha Factor")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_RED,
      "Menu Font Red Color")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_GREEN,
      "Menu Font Green Color")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_BLUE,
      "Menu Font Blue Color")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_FONT,
      "Menu Font")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_CUSTOM,
      "Custom")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_FLATUI,
      "FlatUI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_MONOCHROME,
      "Monochrome")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_MONOCHROME_INVERTED,
      "Monochrome Inverted")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_SYSTEMATIC,
      "Systematic")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_NEOACTIVE,
      "NeoActive")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_PIXEL,
      "Pixel")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_RETROACTIVE,
      "RetroActive")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_RETROSYSTEM,
      "Retrosystem")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_DOTART,
      "Dot-Art")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME,
      "Menu Kleur Thema")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_APPLE_GREEN,
      "Appel Groen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_DARK,
      "Donker")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_DARK_PURPLE,
      "Donker Paars")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_ELECTRIC_BLUE,
      "Elektrisch Blauw")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_GOLDEN,
      "Goud")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_LEGACY_RED,
      "Legacy Red")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_MIDNIGHT_BLUE,
      "Middernacht Blauw")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_PLAIN,
      "Gewoon")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_UNDERSEA,
      "Undersea")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_VOLCANIC_RED,
      "Vulkanisch Rood")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_RIBBON_ENABLE,
      "Menu Shader Pipeline")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_SCALE_FACTOR,
      "Menu Scale Factor")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_SHADOWS_ENABLE,
      "Icon Shadows Enable")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_HISTORY,
      "Geschiedenistab weergeven")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_IMAGES,
      "Afbeeldingentab weergeven")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_MUSIC,
      "Muziektab weergeven")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_SETTINGS,
      "Instellingentab weergeven")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_VIDEO,
      "Videotab weergeven")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_LAYOUT,
      "Menu Layout")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_THEME,
      "Menu Icon Theme")
MSG_HASH(MENU_ENUM_LABEL_VALUE_YES,
      "Ja")
MSG_HASH(MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_TWO,
      "Shader Preset")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_ENABLE,
      "Enable or disable achievements. For more information, visit http://retroachievements.org")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_TEST_UNOFFICIAL,
      "Enable or disable unofficial achievements and/or beta features for testing purposes.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_HARDCORE_MODE_ENABLE,
      "Enable or disable savestates, cheats, rewind, pause, and slow-motion for all games.")
MSG_HASH(MENU_ENUM_SUBLABEL_DRIVER_SETTINGS,
      "Change drivers for this system.")
MSG_HASH(MENU_ENUM_SUBLABEL_RETRO_ACHIEVEMENTS_SETTINGS,
      "Change settings for the achievements.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_SETTINGS,
      "Change settings for the core.")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_SETTINGS,
      "Change settings for the recording.")
MSG_HASH(MENU_ENUM_SUBLABEL_ONSCREEN_DISPLAY_SETTINGS,
      "Change settings for display overlay, keyboard overlay and onscreen notifications.")
MSG_HASH(MENU_ENUM_SUBLABEL_FRAME_THROTTLE_SETTINGS,
      "Change settings for rewinding, fast-forwarding, and slow-motion.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVING_SETTINGS,
      "Change settings for the saving.")
MSG_HASH(MENU_ENUM_SUBLABEL_LOGGING_SETTINGS,
      "Change settings for the logging.")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_INTERFACE_SETTINGS,
      "Change settings for the user interface.")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_SETTINGS,
      "Change accounts, username, and language.")
MSG_HASH(MENU_ENUM_SUBLABEL_PRIVACY_SETTINGS,
      "Change your privacy settings.")
MSG_HASH(MENU_ENUM_SUBLABEL_DIRECTORY_SETTINGS,
      "Change default directories for this system.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_SETTINGS,
      "Change settings for the playlists.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETWORK_SETTINGS,
      "Configure server and network settings.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_CONTENT_LIST,
      "Scan contents and add to the database.")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_SETTINGS,
      "Adjusts settings for audio output.")
MSG_HASH(MENU_ENUM_SUBLABEL_BLUETOOTH_ENABLE,
      "Enable or disable bluetooth.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIG_SAVE_ON_EXIT,
      "Saves changes to configuration file on exit.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIGURATION_SETTINGS,
      "Change default settings for configuration files.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIGURATIONS_LIST,
      "Manage and create configuration files.")
MSG_HASH(MENU_ENUM_SUBLABEL_CPU_CORES,
      "Amount of cores that the CPU has.")
MSG_HASH(MENU_ENUM_SUBLABEL_FPS_SHOW,
      "Displays the current framerate per second onscreen.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_HOTKEY_BINDS,
      "Configure hotkey settings.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_MENU_ENUM_TOGGLE_GAMEPAD_COMBO,
      "Gamepad knoppencombination to toggle menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_SETTINGS,
      "Adjusts settings for joypads, keyboard and mouse.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_USER_BINDS,
      "Configure controls for this user.")
MSG_HASH(MENU_ENUM_SUBLABEL_LOG_VERBOSITY,
      "Enable or disable logging to the terminal.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY,
      "Join or host a netplay session.")
MSG_HASH(MENU_ENUM_SUBLABEL_INFORMATION_LIST_LIST,
      "Toon core, netwerk en systeem informatie.")
MSG_HASH(MENU_ENUM_SUBLABEL_ONLINE_UPDATER,
      "Download add-ons, components and contents for RetroArch.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAMBA_ENABLE,
      "Enable or disable network sharing of your folders.")
MSG_HASH(MENU_ENUM_SUBLABEL_SERVICES_SETTINGS,
      "Manage operating system level services.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHOW_HIDDEN_FILES,
      "Show hidden files/directories inside the file browser.")
MSG_HASH(MENU_ENUM_SUBLABEL_SSH_ENABLE,
      "Enable or disable remote command line access.")
MSG_HASH(MENU_ENUM_SUBLABEL_SUSPEND_SCREENSAVER_ENABLE,
      "Prevents your system's screensaver from becoming active.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_SCALE,
      "Sets the window size relative to the core viewport size. Alternatively you can set a window width and height below for a fixed window size")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_LANGUAGE,
      "Stel de taal in van de gebruikersinterface.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_BLACK_FRAME_INSERTION,
      "Inserts a black frame inbetween frames. Useful for users of 120 Hz screens who want to play 60 Hz material with eliminated ghosting.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FRAME_DELAY,
      "Reduces latency at the cost of higher risk of video stuttering. Adds a delay after V-Sync (in ms).")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_HARD_SYNC_FRAMES,
      "Sets how many frames the CPU can run ahead of the GPU when using 'Hard GPU Sync'.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MAX_SWAPCHAIN_IMAGES,
      "Tells the video driver to explicitly use a specified buffering mode.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MONITOR_INDEX,
      "Selects which display screen to use.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE_AUTO,
      "The accurate estimated refresh rate of the screen in Hz.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE_POLLED,
      "The refresh rate as reported by the display driver.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SETTINGS,
      "Adjusts settings for video output.")
MSG_HASH(MENU_ENUM_SUBLABEL_WIFI_SETTINGS,
      "Scans for wireless networks and establishes connection.")
MSG_HASH(MENU_ENUM_SUBLABEL_HELP_LIST,
      "Leer meer over hoe het werkt.")
MSG_HASH(MSG_APPENDED_DISK,
      "Appended disk")
MSG_HASH(MSG_APPLICATION_DIR,
      "Application Dir")
MSG_HASH(MSG_APPLYING_CHEAT,
      "Applying cheat changes.")
MSG_HASH(MSG_APPLYING_SHADER,
      "Applying shader")
MSG_HASH(MSG_AUDIO_MUTED,
      "Audio muted.")
MSG_HASH(MSG_AUDIO_UNMUTED,
      "Audio unmuted.")
MSG_HASH(MSG_AUTOCONFIG_FILE_ERROR_SAVING,
      "Error saving autoconf file.")
MSG_HASH(MSG_AUTOCONFIG_FILE_SAVED_SUCCESSFULLY,
      "Autoconfig file saved successfully.")
MSG_HASH(MSG_AUTOSAVE_FAILED,
      "Could not initialize autosave.")
MSG_HASH(MSG_AUTO_SAVE_STATE_TO,
      "Auto save state to")
MSG_HASH(MSG_BLOCKING_SRAM_OVERWRITE,
      "Blocking SRAM Overwrite")
MSG_HASH(MSG_BRINGING_UP_COMMAND_INTERFACE_ON_PORT,
      "Bringing up command interface on port")
MSG_HASH(MSG_BYTES,
      "bytes")
MSG_HASH(MSG_CANNOT_INFER_NEW_CONFIG_PATH,
      "Cannot infer new config path. Use current time.")
MSG_HASH(MSG_CHEEVOS_HARDCORE_MODE_ENABLE,
      "Hardcore Mode Enabled, savestate & rewind were disabled.")
MSG_HASH(MSG_COMPARING_WITH_KNOWN_MAGIC_NUMBERS,
      "Comparing with known magic numbers...")
MSG_HASH(MSG_COMPILED_AGAINST_API,
      "Compiled against API")
MSG_HASH(MSG_CONFIG_DIRECTORY_NOT_SET,
      "Config directory not set. Cannot save new config.")
MSG_HASH(MSG_CONNECTED_TO,
      "Connected to")
MSG_HASH(MSG_CONTENT_CRC32S_DIFFER,
      "Content CRC32s differ. Cannot use different games.")
MSG_HASH(MSG_CONTENT_LOADING_SKIPPED_IMPLEMENTATION_WILL_DO_IT,
      "Content loading skipped. Implementation will load it on its own.")
MSG_HASH(MSG_CORE_DOES_NOT_SUPPORT_SAVESTATES,
      "Core does not support save states.")
MSG_HASH(MSG_CORE_OPTIONS_FILE_CREATED_SUCCESSFULLY,
      "Core options file created successfully.")
MSG_HASH(MSG_COULD_NOT_FIND_ANY_NEXT_DRIVER,
      "Could not find any next driver")
MSG_HASH(MSG_COULD_NOT_FIND_COMPATIBLE_SYSTEM,
      "Could not find compatible system.")
MSG_HASH(MSG_COULD_NOT_FIND_VALID_DATA_TRACK,
      "Could not find valid data track")
MSG_HASH(MSG_COULD_NOT_OPEN_DATA_TRACK,
      "could not open data track")
MSG_HASH(MSG_COULD_NOT_READ_CONTENT_FILE,
      "Could not read content file")
MSG_HASH(MSG_COULD_NOT_READ_MOVIE_HEADER,
      "Could not read movie header.")
MSG_HASH(MSG_COULD_NOT_READ_STATE_FROM_MOVIE,
      "Could not read state from movie.")
MSG_HASH(MSG_CRC32_CHECKSUM_MISMATCH,
      "CRC32 checksum mismatch between content file and saved content checksum in replay file header) replay highly likely to desync on playback.")
MSG_HASH(MSG_CUSTOM_TIMING_GIVEN,
      "Custom timing given")
MSG_HASH(MSG_DECOMPRESSION_ALREADY_IN_PROGRESS,
      "Decompression already in progress.")
MSG_HASH(MSG_DECOMPRESSION_FAILED,
      "Decompression failed.")
MSG_HASH(MSG_DETECTED_VIEWPORT_OF,
      "Detected viewport of")
MSG_HASH(MSG_DID_NOT_FIND_A_VALID_CONTENT_PATCH,
      "Did not find a valid content patch.")
MSG_HASH(MSG_DISCONNECT_DEVICE_FROM_A_VALID_PORT,
      "Disconnect device from a valid port.")
MSG_HASH(MSG_DISK_CLOSED,
      "Closed")
MSG_HASH(MSG_DISK_EJECTED,
      "Ejected")
MSG_HASH(MSG_DOWNLOADING,
      "Downloading")
MSG_HASH(MSG_DOWNLOAD_FAILED,
      "Download mislukt")
MSG_HASH(MSG_ERROR,
      "Error")
MSG_HASH(MSG_ERROR_LIBRETRO_CORE_REQUIRES_CONTENT,
      "Libretro core heeft inhoud nodig, maar dat werd niet gegeven.")
MSG_HASH(MSG_ERROR_LIBRETRO_CORE_REQUIRES_SPECIAL_CONTENT,
      "Libretro core heeft speciaal inhoud nodig, maar dat werd niet gegeven.")
MSG_HASH(MSG_ERROR_PARSING_ARGUMENTS,
      "Error parsing arguments.")
MSG_HASH(MSG_ERROR_SAVING_CORE_OPTIONS_FILE,
      "Error saving core options file.")
MSG_HASH(MSG_ERROR_SAVING_REMAP_FILE,
      "Fout is opgetreden tijdens het opslaan van remap bestand.")
MSG_HASH(MSG_ERROR_SAVING_SHADER_PRESET,
      "Fout is opgetreden tijdens het opslaan van shader preset.")
MSG_HASH(MSG_EXTERNAL_APPLICATION_DIR,
      "Externe Applicatie Dir")
MSG_HASH(MSG_EXTRACTING,
      "Uitpakken")
MSG_HASH(MSG_EXTRACTING_FILE,
      "Uitpakken van bestand")
MSG_HASH(MSG_FAILED_SAVING_CONFIG_TO,
      "Fout is opgetrijdens tijdens het opslaan van configuratie naar ")
MSG_HASH(MSG_FAILED_TO,
      "Failed to")
MSG_HASH(MSG_FAILED_TO_ACCEPT_INCOMING_SPECTATOR,
      "Failed to accept incoming spectator.")
MSG_HASH(MSG_FAILED_TO_ALLOCATE_MEMORY_FOR_PATCHED_CONTENT,
      "Failed to allocate memory for patched content...")
MSG_HASH(MSG_FAILED_TO_APPLY_SHADER,
      "Failed to apply shader.")
MSG_HASH(MSG_FAILED_TO_BIND_SOCKET,
      "Failed to bind socket.")
MSG_HASH(MSG_FAILED_TO_CREATE_THE_DIRECTORY,
      "Failed to create the directory.")
MSG_HASH(MSG_FAILED_TO_EXTRACT_CONTENT_FROM_COMPRESSED_FILE,
      "Failed to extract content from compressed file")
MSG_HASH(MSG_FAILED_TO_GET_NICKNAME_FROM_CLIENT,
      "Failed to get nickname from client.")
MSG_HASH(MSG_FAILED_TO_LOAD,
      "Failed to load")
MSG_HASH(MSG_FAILED_TO_LOAD_CONTENT,
      "Failed to load content")
MSG_HASH(MSG_FAILED_TO_LOAD_MOVIE_FILE,
      "Failed to load movie file")
MSG_HASH(MSG_FAILED_TO_LOAD_OVERLAY,
      "Failed to load overlay.")
MSG_HASH(MSG_FAILED_TO_LOAD_STATE,
      "Failed to load state from")
MSG_HASH(MSG_FAILED_TO_OPEN_LIBRETRO_CORE,
      "Failed to open libretro core")
MSG_HASH(MSG_FAILED_TO_PATCH,
      "Failed to patch")
MSG_HASH(MSG_FAILED_TO_RECEIVE_HEADER_FROM_CLIENT,
      "Failed to receive header from client.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME,
      "Failed to receive nickname.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME_FROM_HOST,
      "Failed to receive nickname from host.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME_SIZE_FROM_HOST,
      "Failed to receive nickname size from host.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_SRAM_DATA_FROM_HOST,
      "Failed to receive SRAM data from host.")
MSG_HASH(MSG_FAILED_TO_REMOVE_DISK_FROM_TRAY,
      "Failed to remove disk from tray.")
MSG_HASH(MSG_FAILED_TO_REMOVE_TEMPORARY_FILE,
      "Failed to remove temporary file")
MSG_HASH(MSG_FAILED_TO_SAVE_SRAM,
      "Failed to save SRAM")
MSG_HASH(MSG_FAILED_TO_SAVE_STATE_TO,
      "Failed to save state to")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME,
      "Failed to send nickname.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_SIZE,
      "Failed to send nickname size.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_TO_CLIENT,
      "Failed to send nickname to client.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_TO_HOST,
      "Failed to send nickname to host.")
MSG_HASH(MSG_FAILED_TO_SEND_SRAM_DATA_TO_CLIENT,
      "Failed to send SRAM data to client.")
MSG_HASH(MSG_FAILED_TO_START_AUDIO_DRIVER,
      "Failed to start audio driver. Will continue without audio.")
MSG_HASH(MSG_FAILED_TO_START_MOVIE_RECORD,
      "Failed to start movie record.")
MSG_HASH(MSG_FAILED_TO_START_RECORDING,
      "Failed to start recording.")
MSG_HASH(MSG_FAILED_TO_TAKE_SCREENSHOT,
      "Failed to take screenshot.")
MSG_HASH(MSG_FAILED_TO_UNDO_LOAD_STATE,
      "Failed to undo load state.")
MSG_HASH(MSG_FAILED_TO_UNDO_SAVE_STATE,
      "Failed to undo save state.")
MSG_HASH(MSG_FAILED_TO_UNMUTE_AUDIO,
      "Failed to unmute audio.")
MSG_HASH(MSG_FATAL_ERROR_RECEIVED_IN,
      "Fatal error received in")
MSG_HASH(MSG_FILE_NOT_FOUND,
      "File not found")
MSG_HASH(MSG_FOUND_AUTO_SAVESTATE_IN,
      "Found auto savestate in")
MSG_HASH(MSG_FOUND_DISK_LABEL,
      "Found disk label")
MSG_HASH(MSG_FOUND_FIRST_DATA_TRACK_ON_FILE,
      "Found first data track on file")
MSG_HASH(MSG_FOUND_LAST_STATE_SLOT,
      "Found last state slot")
MSG_HASH(MSG_FOUND_SHADER,
      "Found shader")
MSG_HASH(MSG_FRAMES,
      "Frames")
MSG_HASH(MSG_GAME_SPECIFIC_CORE_OPTIONS_FOUND_AT,
      "Per-Game Options: game-specific core options found at")
MSG_HASH(MSG_GOT_INVALID_DISK_INDEX,
      "Got invalid disk index.")
MSG_HASH(MSG_GRAB_MOUSE_STATE,
      "Grab mouse state")
MSG_HASH(MSG_HW_RENDERED_MUST_USE_POSTSHADED_RECORDING,
      "Libretro core is hardware-geaccelereerd. Must use post-shaded recording as well.")
MSG_HASH(MSG_INFLATED_CHECKSUM_DID_NOT_MATCH_CRC32,
      "Inflated checksum did not match CRC32.")
MSG_HASH(MSG_INPUT_CHEAT,
      "Input Cheat")
MSG_HASH(MSG_INPUT_CHEAT_FILENAME,
      "Input Cheat Filename")
MSG_HASH(MSG_INPUT_PRESET_FILENAME,
      "Input Preset Filename")
MSG_HASH(MSG_INPUT_RENAME_ENTRY,
      "Rename Title")
MSG_HASH(MSG_INTERFACE,
      "Interface")
MSG_HASH(MSG_INTERNAL_STORAGE,
      "Interne Opslag")
MSG_HASH(MSG_REMOVABLE_STORAGE,
      "Removable Storage")
MSG_HASH(MSG_INVALID_NICKNAME_SIZE,
      "Invalid nickname size.")
MSG_HASH(MSG_IN_BYTES,
      "in bytes")
MSG_HASH(MSG_IN_GIGABYTES,
      "in gigabytes")
MSG_HASH(MSG_IN_MEGABYTES,
      "in megabytes")
MSG_HASH(MSG_LIBRETRO_ABI_BREAK,
      "is compiled against a different version of libretro than this libretro implementation.")
MSG_HASH(MSG_LIBRETRO_FRONTEND,
      "Frontend voor libretro")
MSG_HASH(MSG_LOADED_STATE_FROM_SLOT,
      "State geladen van slot #%d.")
MSG_HASH(MSG_LOADED_STATE_FROM_SLOT_AUTO,
      "State geladen van slot #-1 (auto).")
MSG_HASH(MSG_LOADING,
      "Laden")
MSG_HASH(MSG_FIRMWARE,
      "Firmware bestanden ontbreken")
MSG_HASH(MSG_LOADING_CONTENT_FILE,
      "Loading content file")
MSG_HASH(MSG_LOADING_HISTORY_FILE,
      "Loading history file")
MSG_HASH(MSG_LOADING_STATE,
      "Loading state")
MSG_HASH(MSG_MEMORY,
      "Geheugen")
MSG_HASH(MSG_MOVIE_FILE_IS_NOT_A_VALID_BSV1_FILE,
      "Movie file is not a valid BSV1 file.")
MSG_HASH(MSG_MOVIE_FORMAT_DIFFERENT_SERIALIZER_VERSION,
      "Movie format seems to have a different serializer version. Will most likely fail.")
MSG_HASH(MSG_MOVIE_PLAYBACK_ENDED,
      "Movie playback ended.")
MSG_HASH(MSG_MOVIE_RECORD_STOPPED,
      "Stopping movie record.")
MSG_HASH(MSG_NETPLAY_FAILED,
      "Failed to initialize netplay.")
MSG_HASH(MSG_NO_CONTENT_STARTING_DUMMY_CORE,
      "No content, starting dummy core.")
MSG_HASH(MSG_NO_SAVE_STATE_HAS_BEEN_OVERWRITTEN_YET,
      "No save state has been overwritten yet.")
MSG_HASH(MSG_NO_STATE_HAS_BEEN_LOADED_YET,
      "No state has been loaded yet.")
MSG_HASH(MSG_OVERRIDES_ERROR_SAVING,
      "Error saving overrides.")
MSG_HASH(MSG_OVERRIDES_SAVED_SUCCESSFULLY,
      "Overrides saved successfully.")
MSG_HASH(MSG_PAUSED,
      "Gepauzeerd.")
MSG_HASH(MSG_PROGRAM,
      "RetroArch")
MSG_HASH(MSG_READING_FIRST_DATA_TRACK,
      "Reading first data track...")
MSG_HASH(MSG_RECEIVED,
      "ontvangen")
MSG_HASH(MSG_RECORDING_TERMINATED_DUE_TO_RESIZE,
      "Recording terminated due to resize.")
MSG_HASH(MSG_RECORDING_TO,
      "Recording to")
MSG_HASH(MSG_REDIRECTING_CHEATFILE_TO,
      "Redirecting cheat file to")
MSG_HASH(MSG_REDIRECTING_SAVEFILE_TO,
      "Redirecting save file to")
MSG_HASH(MSG_REDIRECTING_SAVESTATE_TO,
      "Redirecting savestate to")
MSG_HASH(MSG_REMAP_FILE_SAVED_SUCCESSFULLY,
      "Remap file saved successfully.")
MSG_HASH(MSG_REMOVED_DISK_FROM_TRAY,
      "Removed disk from tray.")
MSG_HASH(MSG_REMOVING_TEMPORARY_CONTENT_FILE,
      "Removing temporary content file")
MSG_HASH(MSG_RESET,
      "Reset")
MSG_HASH(MSG_RESTARTING_RECORDING_DUE_TO_DRIVER_REINIT,
      "Restarting recording due to driver reinit.")
MSG_HASH(MSG_RESTORED_OLD_SAVE_STATE,
      "Restored old save state.")
MSG_HASH(MSG_RESTORING_DEFAULT_SHADER_PRESET_TO,
      "Shaders: restoring default shader preset to")
MSG_HASH(MSG_REVERTING_SAVEFILE_DIRECTORY_TO,
      "Reverting savefile directory to")
MSG_HASH(MSG_REVERTING_SAVESTATE_DIRECTORY_TO,
      "Reverting savestate directory to")
MSG_HASH(MSG_REWINDING,
      "Rewinding.")
MSG_HASH(MSG_REWIND_INIT,
      "Initializing rewind buffer with size")
MSG_HASH(MSG_REWIND_INIT_FAILED,
      "Failed to initialize rewind buffer. Rewinding will be disabled.")
MSG_HASH(MSG_REWIND_INIT_FAILED_THREADED_AUDIO,
      "Implementation uses threaded audio. Cannot use rewind.")
MSG_HASH(MSG_REWIND_REACHED_END,
      "Reached end of rewind buffer.")
MSG_HASH(MSG_SAVED_NEW_CONFIG_TO,
      "Saved new config to")
MSG_HASH(MSG_SAVED_STATE_TO_SLOT,
      "Saved state to slot #%d.")
MSG_HASH(MSG_SAVED_STATE_TO_SLOT_AUTO,
      "Saved state to slot #-1 (auto).")
MSG_HASH(MSG_SAVED_SUCCESSFULLY_TO,
      "Saved successfully to")
MSG_HASH(MSG_SAVING_RAM_TYPE,
      "Saving RAM type")
MSG_HASH(MSG_SAVING_STATE,
      "Saving state")
MSG_HASH(MSG_SCANNING,
      "Scanning")
MSG_HASH(MSG_SCANNING_OF_DIRECTORY_FINISHED,
      "Scannen van directory voltooid")
MSG_HASH(MSG_SENDING_COMMAND,
      "Sending command")
MSG_HASH(MSG_SEVERAL_PATCHES_ARE_EXPLICITLY_DEFINED,
      "Several patches are explicitly defined, ignoring all...")
MSG_HASH(MSG_SHADER,
      "Shader")
MSG_HASH(MSG_SHADER_PRESET_SAVED_SUCCESSFULLY,
      "Shader preset saved successfully.")
MSG_HASH(MSG_SKIPPING_SRAM_LOAD,
      "Skipping SRAM load.")
MSG_HASH(MSG_SLOW_MOTION,
      "Slow motion.")
MSG_HASH(MSG_FAST_FORWARD,
      "Snel vooruit.")
MSG_HASH(MSG_SLOW_MOTION_REWIND,
      "Slow motion rewind.")
MSG_HASH(MSG_SRAM_WILL_NOT_BE_SAVED,
      "SRAM zal niet opgeslagen worden.")
MSG_HASH(MSG_STARTING_MOVIE_PLAYBACK,
      "Starting movie playback.")
MSG_HASH(MSG_STARTING_MOVIE_RECORD_TO,
      "Starting movie record to")
MSG_HASH(MSG_STATE_SIZE,
      "State size")
MSG_HASH(MSG_STATE_SLOT,
      "State slot")
MSG_HASH(MSG_TAKING_SCREENSHOT,
      "Schermafdruk maken.")
MSG_HASH(MSG_TO,
      "to")
MSG_HASH(MSG_UNDID_LOAD_STATE,
      "Laden van state ongedaan gemaakt.")
MSG_HASH(MSG_UNDOING_SAVE_STATE,
      "Save state ongedaan maken")
MSG_HASH(MSG_UNKNOWN,
      "Onbekend")
MSG_HASH(MSG_UNPAUSED,
      "Unpaused.")
MSG_HASH(MSG_UNRECOGNIZED_COMMAND,
      "Unrecognized command")
MSG_HASH(MSG_USING_CORE_NAME_FOR_NEW_CONFIG,
      "Using core name for new config.")
MSG_HASH(MSG_USING_LIBRETRO_DUMMY_CORE_RECORDING_SKIPPED,
      "Using libretro dummy core. Skipping recording.")
MSG_HASH(MSG_VALUE_CONNECT_DEVICE_FROM_A_VALID_PORT,
      "Connect device from a valid port.")
MSG_HASH(MSG_VALUE_DISCONNECTING_DEVICE_FROM_PORT,
      "Disconnecting device from port")
MSG_HASH(MSG_VALUE_REBOOTING,
      "Opnieuw opstarten...")
MSG_HASH(MSG_VALUE_SHUTTING_DOWN,
      "Afsluiten...")
MSG_HASH(MSG_VERSION_OF_LIBRETRO_API,
      "Versie van libretro API")
MSG_HASH(MSG_VIEWPORT_SIZE_CALCULATION_FAILED,
      "Viewport size calculation failed! Will continue using raw data. This will probably not work right ...")
MSG_HASH(MSG_VIRTUAL_DISK_TRAY,
      "virtual disk tray.")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_LATENCY,
      "Desired audio latency in milliseconds. Might not be honored if the audio driver can't provide given latency.")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MUTE,
      "Mute/unmute audio.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_RATE_CONTROL_DELTA,
      "Helps smooth out imperfections in timing when synchronizing audio and video at the same time. Be aware that if disabled, proper synchronization is nearly impossible to obtain."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CAMERA_ALLOW,
      "Allow or disallow camera access by cores."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LOCATION_ALLOW,
      "Allow or disallow location services access by cores."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_MAX_USERS,
      "Maximum amount of users supported by RetroArch."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_POLL_TYPE_BEHAVIOR,
      "Influence how input polling is done inside RetroArch. Setting it to 'Early' or 'Late' can result in less latency, depending on your configuration."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_ALL_USERS_CONTROL_MENU,
      "Allows any user to control the menu. If disabled, only User 1 can control the menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_VOLUME,
      "Audio volume (in dB). 0 dB is normal volume, no gain applied."
      )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_SYNC,
   "Synchroniseer audio. Aangeraden."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_AXIS_THRESHOLD,
   "How far an axis must be tilted to result in a button press."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_BIND_TIMEOUT,
   "Amount of seconds to wait until proceeding to the next bind."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_TURBO_PERIOD,
   "Describes the period of which turbo-enabled buttons toggle. Numbers are described in frames."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_DUTY_CYCLE,
   "Describes how long the period of a turbo-enabled button should be. Numbers are described in frames."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_VSYNC,
   "Synchronizes the output video of the graphics card to the refresh rate of the screen. Recommended."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_ALLOW_ROTATE,
   "Allow cores to set rotation. When disabled, rotation requests are ignored. Useful for setups where one manually rotates the screen."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_DUMMY_ON_CORE_SHUTDOWN,
   "Some cores might have a shutdown feature. If enabled, it will prevent the core from shutting RetroArch down. Instead, it loads a dummy core."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_CHECK_FOR_MISSING_FIRMWARE,
   "Check if all the required firmware is present before attempting to load content."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE,
   "Verticale refresh rate van je scherm. Wordt gebruikt om een toepasselijke audio input rate te calculeren. LET OP: Deze optie wordt genegeerd als 'Threaded Video' is ingeschakeld."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_ENABLE,
   "Enable audio output."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_MAX_TIMING_SKEW,
   "The maximum change in audio input rate. You may want to increase this to enable very large changes in timing, for example running PAL cores on NTSC displays, at the cost of inaccurate audio pitch."
   )
MSG_HASH(
   MSG_FAILED,
   "gefaald"
   )
MSG_HASH(
   MSG_SUCCEEDED,
   "succeeded"
   )
MSG_HASH(
   MSG_DEVICE_NOT_CONFIGURED,
   "niet geconfigureerd"
   )
MSG_HASH(
   MSG_DEVICE_NOT_CONFIGURED_FALLBACK,
   "not configured, using fallback"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST,
   "Database Cursor List"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_DEVELOPER,
   "Database - Filter : Ontwikkelaar"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_PUBLISHER,
   "Database - Filter : Uitgever"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DISABLED,
   "Uitgeschakeld"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_ENABLED,
   "Ingeschakeld"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_CONTENT_HISTORY_PATH,
   "Content History Path"
   )
MSG_HASH(
      MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_ORIGIN,
      "Database - Filter : Origin")
MSG_HASH(MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_FRANCHISE,
      "Database - Filter : Franchise")
MSG_HASH(MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_ESRB_RATING,
      "Database - Filter : ESRB Rating")
MSG_HASH(MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_ELSPA_RATING,
      "Database - Filter : ELSPA Rating")
MSG_HASH(MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_PEGI_RATING,
      "Database - Filter : PEGI Rating")
MSG_HASH(MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_CERO_RATING,
      "Database - Filter : CERO Rating")
MSG_HASH(MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_BBFC_RATING,
      "Database - Filter : BBFC Rating")
MSG_HASH(MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_MAX_USERS,
      "Database - Filter : Max Users")
MSG_HASH(MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_RELEASEDATE_BY_MONTH,
      "Database - Filter : Releasedate By Month")
MSG_HASH(MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_RELEASEDATE_BY_YEAR,
      "Database - Filter : Releasedate By Year")
MSG_HASH(MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_EDGE_MAGAZINE_ISSUE,
      "Database - Filter : Edge Magazine Issue")
MSG_HASH(MENU_ENUM_LABEL_DATABASE_CURSOR_LIST_ENTRY_EDGE_MAGAZINE_RATING,
      "Database - Filter : Edge Magazine Rating")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_DATABASE_INFO,
      "Database Info")
MSG_HASH(MENU_ENUM_SUBLABEL_PAUSE_NONACTIVE,
      "Pause gameplay when window focus is lost.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_DISABLE_COMPOSITION,
      "Enable or disable composition.")
MSG_HASH(MENU_ENUM_SUBLABEL_HISTORY_LIST_ENABLE,
      "Enable or disable recent playlist for games, images, music, and videos.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_HISTORY_SIZE,
      "Limit the number of entries in recent playlist for games, images, music, and videos.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_UNIFIED_MENU_CONTROLS,
      "Unified Menu Controls")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_UNIFIED_MENU_CONTROLS,
      "Use the same controls for both the menu and the game. Applies to the keyboard.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_ENABLE,
      "Show onscreen messages.")
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_URL_LIST,
      "Browse URL"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_URL,
      "URL Path"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_START,
      "Start"
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_BOKEH,
      "Bokeh")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SNOWFLAKE,
      "Sneeuwvlok")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_REFRESH_ROOMS,
      "Refresh Room List")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ROOM_NICKNAME,
      "Nickname: %s")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ROOM_NICKNAME_LAN,
      "Nickname (lan): %s")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_COMPAT_CONTENT_FOUND,
      "Compatible content found")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_CROP_OVERSCAN,
      "Cuts off a few pixels around the edges of the image customarily left blank by developers which sometimes also contain garbage pixels.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SMOOTH,
      "Adds a slight blur to the image to take the edge off of the hard pixel edges. This option has very little impact on performance.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FILTER,
      "Apply a CPU-powered video filter. NOTE: Might come at a high performance cost. Some video filters might only work for cores that use 32bit or 16bit color.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_USERNAME,
      "Input the username of your Retro Achievements account.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_PASSWORD,
      "Input the password of your Retro Achievements account.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_NICKNAME,
      "Input your user name here. This will be used for netplay sessions, among other things.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_POST_FILTER_RECORD,
      "Capture the image after filters (but not shaders) are applied. Your video will look as fancy as what you see on your screen.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_LIST,
      "Select which core to use.")
MSG_HASH(MENU_ENUM_SUBLABEL_LOAD_CONTENT_LIST,
      "Select which content to start.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETWORK_INFORMATION,
      "Show network interface(s) and associated IP addresses.")
MSG_HASH(MENU_ENUM_SUBLABEL_SYSTEM_INFORMATION,
      "Show information specific to the device.")
MSG_HASH(MENU_ENUM_SUBLABEL_QUIT_RETROARCH,
      "Sluit het programma af.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_WIDTH,
      "Set the custom width size for the display window. Leaving it at 0 will attempt to scale the window as large as possible.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_HEIGHT,
      "Set the custom height size for the display window. Leaving it at 0 will attempt to scale the window as large as possible.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN_X,
      "Set the custom width size for the non-windowed fullscreen mode. Leaving it at 0 will use the desktop resolution.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN_Y,
      "Set the custom height size for the non-windowed fullscreen mode. Leaving it at 0 will use the desktop resolution")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MESSAGE_POS_X,
      "Specify custom X axis position for onscreen text.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MESSAGE_POS_Y,
      "Specify custom Y axis position for onscreen text.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_SIZE,
      "Specify the font size in points.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_OVERLAY_HIDE_IN_MENU,
      "Hide the overlay while inside the menu, and show it again when exiting the menu.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_COLLECTION_LIST,
      "Scanned content will appear here."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SCALE_INTEGER,
      "Only scales video in integer steps. The base size depends on system-reported geometry and aspect ratio. If 'Force Aspect' is not set, X/Y will be integer scaled independently."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_GPU_SCREENSHOT,
      "Screenshots output of GPU shaded material if available."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_ROTATION,
      "Forces a certain rotation of the screen. The rotation is added to rotations which the core sets."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FORCE_SRGB_DISABLE,
      "Forcibly disable sRGB FBO support. Some Intel OpenGL drivers on Windows have video problems with sRGB FBO support if this is enabled. Enabling this can work around it."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN,
      "Start in fullscreen. Can be changed at runtime."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_WINDOWED_FULLSCREEN,
      "If fullscreen, prefer using a windowed fullscreen mode."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_GPU_RECORD,
      "Records output of GPU shaded material if available."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_INDEX,
      "When making a savestate, save state index is automatically increased before it is saved. When loading content, the index will be set to the highest existing index."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_BLOCK_SRAM_OVERWRITE,
      "Block Save RAM from being overwritten when loading save states. Might potentially lead to buggy games."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_FASTFORWARD_RATIO,
      "The maximum rate at which content will be run when using fast forward (e.g., 5.0x for 60 fps content = 300 fps cap). If set to 0.0x, fastforward ratio is unlimited (no FPS cap)."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SLOWMOTION_RATIO,
      "When in slow motion, content will slow down by the factor specified/set."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_REWIND_ENABLE,
      "Enable rewinding. This will take a performance hit when playing."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_REWIND_GRANULARITY,
      "When rewinding a defined number of frames, you can rewind several frames at a time, increasing the rewind speed."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LIBRETRO_LOG_LEVEL,
      "Sets log level for cores. If a log level issued by a core is below this value, it is ignored."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_PERFCNT_ENABLE,
      "Enable performance counters for RetroArch (and cores)."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_SAVE,
      "Automatically makes a savestate at the end of RetroArch's runtime. RetroArch will automatically load this savestate if 'Auto Load State' is enabled."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_LOAD,
      "Automatically load the auto save state on startup."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_THUMBNAIL_ENABLE,
      "Show thumbnails of save states inside the menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTOSAVE_INTERVAL,
      "Autosaves the non-volatile Save RAM at a regular interval. This is disabled by default unless set otherwise. The interval is measured in seconds. A value of 0 disables autosave."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_REMAP_BINDS_ENABLE,
      "If enabled, overrides the input binds with the remapped binds set for the current core."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_AUTODETECT_ENABLE,
      "Enable input auto-detection. Will attempt to autoconfigure joypads, Plug-and-Play style."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_INPUT_SWAP_OK_CANCEL,
      "Swap buttons for OK/Cancel. Disabled is the Japanese button orientation, enabled is the western orientation."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_PAUSE_LIBRETRO,
      "If disabled, the content will keep running in the background when RetroArch's menu is toggled."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_DRIVER,
      "Video driver to use."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DRIVER,
      "Audio driver to use."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_DRIVER,
      "Input driver to use. Depending on the video driver, it might force a different input driver."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_JOYPAD_DRIVER,
      "Joypad driver to use."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_RESAMPLER_DRIVER,
      "Audio resampler driver to use."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CAMERA_DRIVER,
      "Camera driver to use."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LOCATION_DRIVER,
      "Location driver to use."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_DRIVER,
      "Menu driver to use."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_RECORD_DRIVER,
      "Record driver to use."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_WIFI_DRIVER,
      "WiFi driver to use."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NAVIGATION_BROWSER_FILTER_SUPPORTED_EXTENSIONS_ENABLE,
      "Filter files being shown in filebrowser by supported extensions."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_WALLPAPER,
      "Select an image to set as menu wallpaper."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_DYNAMIC_WALLPAPER,
      "Dynamically load a new wallpaper depending on context."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DEVICE,
      "Override the default audio device the audio driver uses. This is driver dependent."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DSP_PLUGIN,
      "Audio DSP plugin that processes audio before it's sent to the driver."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_OUTPUT_RATE,
      "Audio output sample rate."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_OPACITY,
      "Opacity of all UI elements of the overlay."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_SCALE,
      "Scale of all UI elements of the overlay."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_OVERLAY_ENABLE,
      "Enable the overlay."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_PRESET,
      "Select an overlay from the file browser."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_IP_ADDRESS,
      "The address of the host to connect to."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_TCP_UDP_PORT,
      "The port of the host IP address. Can be either a TCP or UDP port."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_PASSWORD,
      "The password for connecting to the netplay host. Used only in host mode."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_PUBLIC_ANNOUNCE,
      "Whether to announce netplay games publicly. If unset, clients must manually connect rather than using the public lobby."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_SPECTATE_PASSWORD,
      "The password for connecting to the netplay host with only spectator privileges. Used only in host mode."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_START_AS_SPECTATOR,
      "Whether to start netplay in spectator mode."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_ALLOW_SLAVES,
      "Whether to allow connections in slave mode. Slave-mode clients require very little processing power on either side, but will suffer significantly from network latency."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_REQUIRE_SLAVES,
      "Whether to disallow connections not in slave mode. Not recommended except for very fast networks with very weak machines."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_STATELESS_MODE,
      "Whether to run netplay in a mode not requiring save states. If set to true, a very fast network is required, but no rewinding is performed, so there will be no netplay jitter."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_CHECK_FRAMES,
      "The frequency in frames with which netplay will verify that the host and client are in sync."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_NAT_TRAVERSAL,
      "When hosting, attempt to listen for connections from the public Internet, using UPnP or similar technologies to escape LANs."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_STDIN_CMD_ENABLE,
      "Enable stdin command interface."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MOUSE_ENABLE,
      "Enable mouse controls inside the menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_POINTER_ENABLE,
      "Enable touch controls inside the menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_THUMBNAILS,
      "Type of thumbnail to display."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_TIMEDATE_ENABLE,
      "Shows current date and/or time inside the menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_BATTERY_LEVEL_ENABLE,
      "Shows current battery level inside the menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NAVIGATION_WRAPAROUND,
      "Wrap-around to beginning and/or end if boundary of list is reached horizontally or vertically."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_ENABLE_HOST,
      "Enables netplay in host (server) mode."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_ENABLE_CLIENT,
      "Enables netplay in client mode.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_DISCONNECT,
      "Disconnects an active Netplay connection.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCAN_DIRECTORY,
      "Scans a directory for compatible files and add them to the collection.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCAN_FILE,
      "Scans a compatible file and add it to the collection.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SWAP_INTERVAL,
      "Uses a custom swap interval for Vsync. Set this to effectively halve monitor refresh rate."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SORT_SAVEFILES_ENABLE,
      "Sort save files in folders named after the core used."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SORT_SAVESTATES_ENABLE,
      "Sort save states in folders named after the core used."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_UPDATER_BUILDBOT_URL,
      "URL to core updater directory on the Libretro buildbot.")
MSG_HASH(MENU_ENUM_SUBLABEL_BUILDBOT_ASSETS_URL,
      "URL to assets updater directory on the Libretro buildbot.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_UPDATER_AUTO_EXTRACT_ARCHIVE,
      "After downloading, automatically extract files contained in the downloaded archives."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_REFRESH_ROOMS,
      "Scan for new rooms.")
MSG_HASH(MENU_ENUM_SUBLABEL_DELETE_ENTRY,
      "Remove this entry from the collection.")
MSG_HASH(MENU_ENUM_SUBLABEL_INFORMATION,
      "View more information about the content.")
MSG_HASH(MENU_ENUM_SUBLABEL_RUN,
      "Start the content.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_FILE_BROWSER_SETTINGS,
      "Adjusts filebrowser settings.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTO_REMAPS_ENABLE,
      "Enable customized controls by default at startup."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTO_OVERRIDES_ENABLE,
      "Enable customized configuration by default at startup."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_GAME_SPECIFIC_OPTIONS,
      "Enable customized core options by default at startup.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_ENABLE,
      "Shows current core name inside menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_DATABASE_MANAGER,
      "View databases.")
MSG_HASH(MENU_ENUM_SUBLABEL_CURSOR_MANAGER,
      "View previous searches.")
MSG_HASH(MENU_ENUM_SUBLABEL_TAKE_SCREENSHOT,
      "Captures an image of the screen.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CLOSE_CONTENT,
      "Closes the current content. Any unsaved changes might be lost."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_LOAD_STATE,
      "Load a saved state from the currently selected slot.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_STATE,
      "Save a state to the currently selected slot.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESUME,
      "Resume the currently running content and leave the Quick Menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESUME_CONTENT,
      "Resume the currently running content and leave the Quick Menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_STATE_SLOT,
      "Changes the currently selected state slot.")
MSG_HASH(MENU_ENUM_SUBLABEL_UNDO_LOAD_STATE,
      "If a state was loaded, content will go back to the state prior to loading.")
MSG_HASH(MENU_ENUM_SUBLABEL_UNDO_SAVE_STATE,
      "If a state was overwritten, it will roll back to the previous save state.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_ACCOUNTS_RETRO_ACHIEVEMENTS,
      "Retro Achievements service. For more information, visit http://retroachievements.org"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_ACCOUNTS_LIST,
      "Manages currently configured accounts."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_META_REWIND,
      "Manages rewind settings.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESTART_CONTENT,
      "Restarts the content from the beginning.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_CURRENT_CONFIG_OVERRIDE_CORE,
      "Saves an override configuration file which will apply for all content loaded with this core. Will take precedence over the main configuration.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_CURRENT_CONFIG_OVERRIDE_GAME,
      "Saves an override configuration file which will apply for the current content only. Will take precedence over the main configuration.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_CHEAT_OPTIONS,
      "Set up cheat codes.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHADER_OPTIONS,
      "Set up shaders to visually augment the image.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_INPUT_REMAPPING_OPTIONS,
      "Change the controls for the currently running content.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_OPTIONS,
      "Change the options for the currently running content.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHOW_ADVANCED_SETTINGS,
      "Show advanced settings for power users (hidden by default).")
MSG_HASH(MENU_ENUM_SUBLABEL_THREADED_DATA_RUNLOOP_ENABLE,
      "Perform tasks on a separate thread.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_ENTRY_REMOVE,
      "Allow the user to remove entries from collections.")
MSG_HASH(MENU_ENUM_SUBLABEL_SYSTEM_DIRECTORY,
      "Sets the System directory. Cores can query for this directory to load BIOSes, system-specific configs, etc.")
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_BROWSER_DIRECTORY,
      "Sets start directory for the filebrowser.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_DIR,
      "Usually set by developers who bundle libretro/RetroArch apps to point to assets."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_DYNAMIC_WALLPAPERS_DIRECTORY,
      "Directory to store wallpapers dynamically loaded by the menu depending on context.")
MSG_HASH(MENU_ENUM_SUBLABEL_THUMBNAILS_DIRECTORY,
      "Supplementary thumbnails (boxarts/misc. images, etc.) are stored here."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_CONFIG_DIRECTORY,
      "Sets start directory for menu configuration browser.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_INPUT_LATENCY_FRAMES_MIN,
      "The number of frames of input latency for netplay to use to hide network latency. Reduces jitter and makes netplay less CPU-intensive, at the expense of noticeable input lag.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_INPUT_LATENCY_FRAMES_RANGE,
      "The range of frames of input latency that may be used to hide network latency. Reduces jitter and makes netplay less CPU-intensive, at the expense of unpredictable input lag.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_CYCLE_TRAY_STATUS,
      "Cycle the current disk. If the disk is inserted, it will eject the disk. If the disk has not been inserted, it will be inserted. ")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_INDEX,
      "Change the disk index.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_OPTIONS,
      "Disk image management.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_IMAGE_APPEND,
      "Select a disk image to insert.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_ENUM_THROTTLE_FRAMERATE,
      "Makes sure the framerate is capped while inside the menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_LAYOUT,
      "Select a different layout for the XMB interface.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_THEME,
      "Select a different theme for the icon. Changes will take effect after you restart the program.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_SHADOWS_ENABLE,
      "Enable drop shadows for all icons. This will have a minor performance hit.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_COLOR_THEME,
      "Select a different background color gradient theme.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_WALLPAPER_OPACITY,
      "Modify the opacity of the background wallpaper.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_MENU_COLOR_THEME,
      "Select a different background color gradient theme.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_RIBBON_ENABLE,
      "Select an animated background effect. Can be GPU-intensive depending on the effect. If performance is unsatisfactory, either turn this off or revert to a simpler effect.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_FONT,
      "Select a different main font to be used by the menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_IMAGES,
      "Show the image tab inside the main menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_MUSIC,
      "Show the music tab inside the main menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_VIDEO,
      "Show the video tab inside the main menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_NETPLAY,
      "Show the netplay tab inside the main menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_SETTINGS,
      "Show the settings tab inside the main menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_HISTORY,
      "Show the recent history tab inside the main menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_ADD,
      "Show the import content tab inside the main menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_PLAYLISTS,
      "Show playlist tabs inside the main menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_SHOW_START_SCREEN,
      "Show startup screen in menu. This is automatically set to false after the program starts for the first time.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_HEADER_OPACITY,
      "Modify the opacity of the header graphic.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_FOOTER_OPACITY,
      "Modify the opacity of the footer graphic.")
MSG_HASH(MENU_ENUM_SUBLABEL_DPI_OVERRIDE_ENABLE,
      "The menu normally scales itself dynamically. If you want to set a specific scaling size instead, enable this.")
MSG_HASH(MENU_ENUM_SUBLABEL_DPI_OVERRIDE_VALUE,
      "Set the custom scaling size here. NOTE: You have to enable 'DPI Override' for this scaling size to take effect.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_ASSETS_DIRECTORY,
      "Save all downloaded files to this directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_REMAPPING_DIRECTORY,
      "Save all remapped controls to this directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_LIBRETRO_DIR_PATH,
      "Directory where the program searches for content/cores.")
MSG_HASH(MENU_ENUM_SUBLABEL_LIBRETRO_INFO_PATH,
      "Application/core information files are stored here.")
MSG_HASH(MENU_ENUM_SUBLABEL_JOYPAD_AUTOCONFIG_DIR,
      "If a joypad is plugged in, that joypad will be autoconfigured if a config file corresponding to it is present inside this directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_DIRECTORY,
      "Save all collections to this directory.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CACHE_DIRECTORY,
      "If set to a directory, content which is temporarily extracted (e.g. from archives) will be extracted to this directory."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CURSOR_DIRECTORY,
      "Bewaarde queries worden in deze directory opgeslagen.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_DATABASE_DIRECTORY,
      "Databases worden in deze directory opgeslagen."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_ASSETS_DIRECTORY,
      "This location is queried by default when menu interfaces try to look for loadable assets, etc."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SAVEFILE_DIRECTORY,
      "Save all save files to this directory. If not set, will try to save inside the content file's working directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVESTATE_DIRECTORY,
      "Save all save states to this directory. If not set, will try to save inside the content file's working directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCREENSHOT_DIRECTORY,
      "Directory to dump screenshots to.")
MSG_HASH(MENU_ENUM_SUBLABEL_OVERLAY_DIRECTORY,
      "Defines a directory where overlays are kept for easy access.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_DATABASE_PATH,
      "Cheat files are kept here."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_FILTER_DIR,
      "Directory where audio DSP filter files are kept."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FILTER_DIR,
      "Directory where CPU-based video filter files are kept."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_DIR,
      "Defines a directory where GPU-based video shader files are kept for easy access.")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_OUTPUT_DIRECTORY,
      "Recordings will be dumped to this directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_CONFIG_DIRECTORY,
      "Recording configurations will be kept here.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_PATH,
      "Select a different font for onscreen notifications.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHADER_APPLY_CHANGES,
      "Changes to the shader configuration will take effect immediately. Use this if you changed the amount of shader passes, filtering, FBO scale, etc.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SHADER_NUM_PASSES,
      "Increase or decrease the amount of shader pipeline passes. You can bind a separate shader to each pipeline pass and configure its scale and filtering."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET,
      "Load a shader preset. The shader pipeline will be automatically set-up.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_AS,
      "Save the current shader settings as a new shader preset.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_CORE,
      "Save the current shader settings as the default settings for this application/core.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_GAME,
      "Save the current shader settings as the default settings for the content.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PARAMETERS,
      "Modifies the current shader directly. Changes will not be saved to the preset file.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_PARAMETERS,
      "Modifies the shader preset itself currently used in the menu.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_NUM_PASSES,
      "Increase or decrease the amount of cheats."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CHEAT_APPLY_CHANGES,
      "Cheat changes will take effect immediately.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_FILE_LOAD,
      "Load a cheat file."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_FILE_SAVE_AS,
      "Save current cheats as a save file."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SETTINGS,
      "Quickly access all relevant in-game settings.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_INFORMATION,
      "View information pertaining to the application/core.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_ASPECT_RATIO,
      "Floating point value for video aspect ratio (width / height), used if the Aspect Ratio is set to 'Config'.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_HEIGHT,
      "Custom viewport height that is used if the Aspect Ratio is set to 'Custom'.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_WIDTH,
      "Custom viewport width that is used if the Aspect Ratio is set to 'Custom'.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_X,
      "Custom viewport offset used for defining the X-axis position of the viewport. These are ignored if 'Integer Scale' is enabled. It will be automatically centered then.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_Y,
      "Custom viewport offset used for defining the Y-axis position of the viewport. These are ignored if 'Integer Scale' is enabled. It will be automatically centered then.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_USE_MITM_SERVER,
      "Gebruik Relay Server")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_USE_MITM_SERVER,
      "Forward netplay connections through a man-in-the-middle server. Useful if the host is behind a firewall or has NAT/UPnP problems.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER,
      "Aan audio mixer toevoegen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_PLAY,
      "Aan audio mixer toevoegen en afspelen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_COLLECTION,
      "Aan audio mixer toevoegen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_COLLECTION_AND_PLAY,
      "Add to mixer and play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FILTER_BY_CURRENT_CORE,
      "Filter by current core")
MSG_HASH(
      MSG_AUDIO_MIXER_VOLUME,
      "Globale volume voor audio mixer"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_MIXER_VOLUME,
      "Globale volume voor audio mixer (in dB uitgedrukt). 0 dB is het normale geluidsniveau."
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_VOLUME,
      "Audio Mixer Volume Level (dB)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_MUTE,
      "Audio Mixer Mute"
      )
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MIXER_MUTE,
      "Mute/unmute mixer audio.")
MSG_HASH(MENU_ENUM_LABEL_MENU_SHOW_ONLINE_UPDATER,
      "Online Updater Weergeven")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_ONLINE_UPDATER,
      "Show/hide the 'Online Updater' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_CORE_UPDATER,
      "Show Core Updater")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_CORE_UPDATER,
      "Show/hide the ability to update cores (and core info files).")
MSG_HASH(MSG_PREPARING_FOR_CONTENT_SCAN,
      "Preparing for content scan...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_DELETE,
      "Delete core")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_DELETE,
      "Remove this core from disk.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RENAME_ENTRY,
      "Rename the title of the entry.")
MSG_HASH(MENU_ENUM_LABEL_RENAME_ENTRY,
      "Rename")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FRAMEBUFFER_OPACITY,
      "Framebuffer Opacity")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_FRAMEBUFFER_OPACITY,
      "Modify the opacity of the framebuffer.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_FAVORITES,
      "Favorites")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_FAVORITES,
      "Content which you have added to 'Favorites' will appear here.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_MUSIC,
      "Music")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_MUSIC,
      "Music which has been previously played will appear here.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_IMAGES,
      "Image")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_IMAGES,
      "Images which have been previously viewed will appear here.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_VIDEO,
      "Video")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_VIDEO,
      "Videos which have been previously played will appear here.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_ICONS_ENABLE,
      "Menu Icons")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_ICONS_ENABLE,
      "Enable/disable the menu icons shown at the lefthand side of the menu entries.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MAIN_MENU_ENABLE_SETTINGS,
      "Enable Settings Tab")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_SETTINGS_PASSWORD,
      "Set Password For Enabling Settings Tab")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD,
      "Enter Password")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD_OK,
      "Password correct.")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD_NOK,
      "Password incorrect.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_MAIN_MENU_ENABLE_SETTINGS,
      "Enables the Settings tab. A restart is required for the tab to appear.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_SETTINGS_PASSWORD,
      "Supplying a password when hiding the settings tab makes it possible to later restore it from the menu, by going to the Main Menu tab, selecting Enable Settings Tab and entering the password.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_ENTRY_RENAME,
      "Allow the user to rename entries in collections.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_ENTRY_RENAME,
      "Allow to rename entries")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_LOAD_CORE,
      "Toon Core Laden")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_LOAD_CORE,
      "Toon/verberg de 'Laad Core' optie.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_LOAD_CONTENT,
      "Toon Laad Inhoud")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_LOAD_CONTENT,
      "Toon/verberg de 'Laad Inhoud' optie.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_INFORMATION,
      "Toon Informatie")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_INFORMATION,
      "Toon/verberg de 'Informatie' optie.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_CONFIGURATIONS,
      "Toon Configuraties")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_CONFIGURATIONS,
      "Toon/verberg de 'Configuraties' optie.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_HELP,
      "Toon Hulp")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_HELP,
      "Toon/verberg de 'Hulp' optie.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_QUIT_RETROARCH,
      "Toon Sluit RetroArch")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_QUIT_RETROARCH,
      "Toon/verberg de 'Sluit RetroArch' optie.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_REBOOT,
      "Toon Herstart")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_REBOOT,
      "Toon/verberg de 'Herstart' optie.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_VIEWS_SETTINGS,
      "Snelmenu")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_VIEWS_SETTINGS,
      "Toon/verberg elementen op the Snelmenu scherm.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_TAKE_SCREENSHOT,
      "Toon Neem Schermafdruk")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_TAKE_SCREENSHOT,
      "Toon/verberg de 'Neem Schermafdruk' optie.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_LOAD_STATE,
      "Toon Save/Load State")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_LOAD_STATE,
      "Toon/verberg de opties voor saving/loading een state.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_UNDO_SAVE_LOAD_STATE,
      "Toon Save/Load State Ongedaan Maken")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_UNDO_SAVE_LOAD_STATE,
      "Toon/verberg de opties voor saving/loading een state ongedaan te maken.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_ADD_TO_FAVORITES,
      "Show Add to Favorites")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_ADD_TO_FAVORITES,
      "Show/hide the 'Add to Favorites' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_OPTIONS,
      "Toon Opties")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_OPTIONS,
      "Toon/verberg de 'Opties' optie.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_CONTROLS,
      "Toon Besturing")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_CONTROLS,
      "Toon/verberg de 'Besturing' optie.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_CHEATS,
      "Toon Cheats")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_CHEATS,
      "Toon/verberg de 'Cheats' optie.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SHADERS,
      "Toon Shaders")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SHADERS,
      "Toon/verberg de 'Shaders' optie.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_CORE_OVERRIDES,
      "Toon Save Core Overrides")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_CORE_OVERRIDES,
      "Toon/verberg de 'Save Core Overrides' optie.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_GAME_OVERRIDES,
      "Toon Save Game Overrides")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_GAME_OVERRIDES,
      "Toon/verberg de 'Save Game Overrides' optie.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_INFORMATION,
      "Toon Informatie")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_INFORMATION,
      "Toon/verberg de 'Informatie' optie.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_DISABLE_KIOSK_MODE,
      "Kioskmodus Deactiveren")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_DISABLE_KIOSK_MODE,
      "Disables kiosk mode. A restart is required for the change to take full effect.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_ENABLE_KIOSK_MODE,
      "Kioskmodus Activeren")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_ENABLE_KIOSK_MODE,
      "Protects the setup by hiding all configuration related settings.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_KIOSK_MODE_PASSWORD,
      "Set Password For Disabling Kiosk Mode")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_KIOSK_MODE_PASSWORD,
      "Supplying a password when enabling kiosk mode makes it possible to later disable it from the menu, by going to the Main Menu, selecting Disable Kiosk Mode and entering the password.")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD,
      "Enter Password")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD_OK,
      "Wachtwoord correct.")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD_NOK,
      "Verkeerde wachtwoord.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUTOMATICALLY_ADD_CONTENT_TO_PLAYLIST,
      "Automatically add content to playlist")
MSG_HASH(MENU_ENUM_SUBLABEL_AUTOMATICALLY_ADD_CONTENT_TO_PLAYLIST,
      "Automatically scans loaded content so they appear inside playlists.")
MSG_HASH(MSG_SCANNING_OF_FILE_FINISHED,
      "Scanning of file finished")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_RESAMPLER_QUALITY,
      "Audio Resampler Quality")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_RESAMPLER_QUALITY,
      "Lower this value to favor performance/lower latency over audio quality, increase if you want better audio quality at the expense of performance/lower latency.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATISTICS_SHOW,
      "Display Statistics")
MSG_HASH(MENU_ENUM_SUBLABEL_STATISTICS_SHOW,
      "Show onscreen technical statistics.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BORDER_FILLER_ENABLE,
      "Enable border filler")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BORDER_FILLER_THICKNESS_ENABLE,
      "Enable border filler thickness")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BACKGROUND_FILLER_THICKNESS_ENABLE,
      "Enable background filler thickness")
MSG_HASH(MENU_ENUM_SUBLABEL_CRT_SWITCH_RESOLUTION, "For 15 kHz CRT displays only. Attempts to use exact core/game resolution and refresh rate.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CRT_SWITCH_RESOLUTION, "CRT SwitchRes") 
MSG_HASH(MENU_ENUM_SUBLABEL_CRT_SWITCH_RESOLUTION_SUPER, "When CRT SwitchRes is enabled, force ultrawide horizontal resolution to minimize mode switching.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CRT_SWITCH_RESOLUTION_SUPER, "CRT Super Resolution") 
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_REWIND,
      "Show Rewind Settings")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_REWIND,
      "Show/hide the Rewind options.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_LATENCY,
      "Show/hide the Latency options.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_LATENCY,
      "Show Latency Settings")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_OVERLAYS,
      "Show/hide the Overlay options.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_OVERLAYS,
      "Show Overlay Settings")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_ENABLE_MENU,
      "Enable menu audio")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_ENABLE_MENU,
      "Enable or disable menu sound.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_SETTINGS,
      "Mixer Settings")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MIXER_SETTINGS,
      "View and/or modify audio mixer settings.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_OVERRIDE_OPTIONS,
      "Configuration Override options")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_OVERRIDE_OPTIONS,
      "Options for overriding the global configuration.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY,
      "Will start playback of the audio stream. Once finished, it will remove the current audio stream from memory.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY_LOOPED,
      "Will start playback of the audio stream. Once finished, it will loop and play the track again from the beginning.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY_SEQUENTIAL,
      "Will start playback of the audio stream. Once finished, it will jump to the next audio stream in sequential order and repeat this behavior. Useful as an album playback mode.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_STOP,
      "This will stop playback of the audio stream, but not remove it from memory. You can start playing it again by selecting 'Play'.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_REMOVE,
      "This will stop playback of the audio stream and remove it entirely from memory.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_VOLUME,
      "Adjust the volume of the audio stream.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_MIXER,
      "Add this audio track to an available audio stream slot. If no slots are currently available, it will be ignored.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_MIXER_AND_PLAY,
      "Add this audio track to an available audio stream slot and play it. If no slots are currently available, it will be ignored.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY,
      "Play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY_LOOPED,
      "Play (Looped)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY_SEQUENTIAL,
      "Play (Sequential)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_STOP,
      "Stop")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_REMOVE,
      "Remove")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_VOLUME,
      "Volume")
